<?php

namespace HCM\BTL\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use BancoTalentos;
use Zeedhi\Framework\DTO\Request\Row;
use Controller\ValoresDefault;
use HCM\Util\DateUtil;
use HCM\Geral\Services\OperadorService;
use HCM\Geral\Services\VinculoServices;
use HCM\BTL\Services\FinalizarProcessoService;
use HCM\Util\HCMParameters;
use HCM\Util\Util;
use Doctrine\ORM\EntityManager;

class FinalizarProcessoController extends Crud {

    protected $operadorService;
    protected $entityManager;
    protected $hcmParameters;
    protected $finalizarProcessoService;

    public function __construct (Manager $dataSourceManager, OperadorService $operadorService, HCMParameters $hcmParameters, EntityManager $entityManager, Util $util, VinculoServices $vinculoServices, FinalizarProcessoService $finalizarProcessoService){
        $this->operadorService = $operadorService;
        $this->hcmParameters   = $hcmParameters;
        $this->entityManager = $entityManager;
        $this->util = $util;
        $this->vinculoServices = $vinculoServices;
        $this->finalizarProcessoService = $finalizarProcessoService;
        $this->objects = array();
        $this->objPartProcesso = array();
        $this->altebancohoras = array();
        $this->progocorrencia = array();

    	parent::__construct($dataSourceManager);
    }

    public function salvaParcNegocio(DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            $this->finalizarProcessoService->updateNovoCodigo($request->getDataSet()->getRows()[0]['NRORG']);
            foreach($request->getDataSet()->getRows() as &$row) {
                
                $dtmescompetencia = str_split(DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString($row['DTADMISSAOVINC']))->__toString(), 10);
                $dtmescompetencia = $dtmescompetencia[0];
                $row['__is_new'] = true;

                $email = explode('@', $row['DSEMAILOPER']);
                $row['DSEMAILOPER'] = $email[0].'_admissao'.'@'.$email[1];

                $row['NMOPERADOR'] = $this->util->removeCaracteresEspeciais($row['NMOPERADOR']);
                $row['NMOPERADOR'] = strtoupper($row['NMOPERADOR']);
                
                $row['NRORG_PADRAO'] = $this->hcmParameters->getNrorgPadrao();

                $row['NMPRINCIPALPARC'] = isset($row['NMPRINCIPALPARC'])?$row['NMPRINCIPALPARC']:$row['NMOPERADOR'];
                
                $row['NMSECUNDARIPARC'] = isset($row['NMSECUNDARIPARC'])?$row['NMSECUNDARIPARC']:$row['NMOPERADOR'];

                $row['DTNASCIFUNDPARC'] = isset($row['DTNASCIFUNDPARC'])?$row['DTNASCIFUNDPARC']:$row['DTNASCPESSOA'];

                $row['IDATIVO'] = isset($row['IDATIVO'])?$row['IDATIVO']:'S';
                
                $row['NRINSCRICAOPARC'] = isset($row['NRINSCRICAOPARC'])?$row['NRINSCRICAOPARC']:$row['NRCPFPESSOA'];

                $row['CDTIPOPARCPRINCIPAL'] = isset($row['CDTIPOPARCPRINCIPAL'])?$row['CDTIPOPARCPRINCIPAL']:'PESSOA';

                $row['IDPESSOAFISICA'] = isset($row['IDPESSOAFISICA'])?$row['IDPESSOAFISICA']:'S';

                $row['IDINSTITUICAO'] = isset($row['IDINSTITUICAO'])?$row['IDINSTITUICAO']:'N';
                
                $row['IDPARCFUNDIDO'] = isset($row['IDPARCFUNDIDO'])?$row['IDPARCFUNDIDO']:'N';

                $row['DTINCLUSAO'] = isset($row['DTINCLUSAO'])?$row['DTINCLUSAO']:date('d/m/Y');

                $row['NRORG'] = isset($row['NRORG'])?$row['NRORG']:$row['NRORGPADRAO'];

                $row['CDOPERINCLUSAO'] = isset($row['CDOPERINCLUSAO'])?$row['CDOPERINCLUSAO']:$this->hcmParameters->getCdoperador();

                $row['NRPARCNEGOCIO_ANTIGO'] = $row['NRPARCNEGOCIO'];

                $row['NRPARCNEGOCIO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'PARCNEGOCIO', 1, 12, true);
                
                $this->objects[] = $this->finalizarProcessoService->salvaParcNegocio($row);
                
            }
            self::salvarPessoa($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarPessoa (DTO\Request\DataSet $request, DTO\Response $response){
        try{
            foreach($request->getDataSet()->getRows() as &$row) {

                $row['NRPESSOA'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_PESSOA', 1, 12, true);
                $row['DTULTATU'] = isset($row['DTULTATU'])?$row['DTULTATU']:$row['DTINCLUSAO'];
                
                $row['CDOPERINCLUSAO'] = isset($row['CDOPERINCLUSAO'])?$row['CDOPERINCLUSAO']:$row['CDOPERADOR_LOG'];
                
                $this->objects[] = $this->finalizarProcessoService->salvarPessoa($row);
            }
            self::salvarPessoaH($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarPessoaH (DTO\Request\DataSet $request, DTO\Response $response){
        try{
            foreach ($request->getDataSet()->getRows() as &$row) {
                list($primeiroNome, $meioNome, $ultimoNome) = self::decompoeNomePessoa($row['NMOPERADOR']);
                $dtmescompetencia = str_split(DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString($row['DTADMISSAOVINC']))->__toString(), 10);
               $dtmescompetencia = $dtmescompetencia[0];

                $row['DTMESCOMPETENC'] = isset($row['DTMESCOMPETENC'])?$row['DTMESCOMPETENC']:$dtmescompetencia;
               
                $row['NMPESSOA'] = $this->util->removeCaracteresEspeciais($row['NMPESSOA']);
                $row['NMPESSOA'] = strtoupper($row['NMPESSOA']);

                $row['NRPESSOAH'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_PESSOAH', 1, 12, true);
                
                $row['DSPRINOMEPESS'] = isset($row['DSPRINOMEPESS'])?$row['DSPRINOMEPESS']:$primeiroNome; 

                $row['DSULTNOMEPESS'] = isset($row['DSULTNOMEPESS'])?$row['DSULTNOMEPESS']:$ultimoNome;

                $row['DSNOMEMEIOPESS'] = isset($row['DSNOMEMEIOPESS'])?$row['DSNOMEMEIOPESS']:$meioNome;

                $row['NRNACIONALID'] = isset($row['NRNACIONALIDADE'])?$row['NRNACIONALIDADE']:null;

                $row['DTCASAPESSOA'] = isset($row['DTCASAPESSOA'])?$row['DTCASAPESSOA']:null;
                
                $row['NRCERTCASAPES'] = isset($row['NRCERTCASAPES'])?$row['NRCERTCASAPES']:null;

                $row['NRRACAPESSOA'] = isset($row['NRRACAPESSOA'])?$row['NRRACAPESSOA']:null;

                $row['NRRGPESSOA'] = isset($row['NRRGPESSOA'])?$row['NRRGPESSOA']:null;

                $row['CDEXRGPESSOA'] = isset($row['CDEXRGPESSOA'])?$row['CDEXRGPESSOA']:null;

                $row['DTEXRGPESSOA'] = isset($row['DTEXRGPESSOA'])?$row['DTEXRGPESSOA']:null;

                $row['DSLOCALEXRGPES'] = isset($row['DSLOCALEXRGPES'])?$row['DSLOCALEXRGPES']:null;

                $row['SGUFRGPESSOA'] = isset($row['SGUFRGPESSOA'])?$row['SGUFRGPESSOA']:null;

                $row['NRTITUELEIPES'] = isset($row['NRTITUELEIPES'])?$row['NRTITUELEIPES']:null;

                $row['NRZONAELEIPES'] = isset($row['NRZONAELEIPES'])?$row['NRZONAELEIPES']:null;

                $row['NRSECAELEIPES'] = isset($row['NRSECAELEIPES'])?$row['NRSECAELEIPES']:null;

                $row['IDISENTITUELEI'] = isset($row['IDISENTITUELEI'])?$row['IDISENTITUELEI']:null;

                $row['NRCARTHABPES'] = isset($row['NRCARTHABPES'])?$row['NRCARTHABPES']:null;

                $row['DSCATEGHABCART'] = isset($row['DSCATEGHABCART'])?$row['DSCATEGHABCART']:null;

                $row['DTVALHABCARTPES'] = isset($row['DTVALHABCARTPES'])?substr($row['DTVALHABCARTPES'],0,10):null;

                $row['NRCTPSPESSOA'] = isset($row['NRCTPSPESSOA'])?$row['NRCTPSPESSOA']:null;

                $row['NRSERIECTPSPES'] = isset($row['NRSERIECTPSPES'])?$row['NRSERIECTPSPES']:null;

                $row['DTCTPSPESSOA'] = isset($row['DTCTPSPESSOA'])?$row['DTCTPSPESSOA']:null;

                $row['SGUFCTPSPES'] = isset($row['SGUFCTPSPES'])?$row['SGUFCTPSPES']:null;

                $row['NRPISPASEPPES'] = isset($row['NRPISPASEPPES'])?$row['NRPISPASEPPES']:null;

                $row['DTINSCPISPASEP'] = isset($row['DTINSCPISPASEP'])?$row['DTINSCPISPASEP']:null;

                $row['NRREGCTPSPES'] = isset($row['NRREGCTPSPES'])?$row['NRREGCTPSPES']:null;

                $row['NRINSCRCONSREG'] = isset($row['NRINSCRCONSREG'])?$row['NRINSCRCONSREG']:null;

                $row['DTEXCONSREG'] = isset($row['DTEXCONSREG'])?$row['DTEXCONSREG']:null;

                $row['SGUFCONSREG'] = isset($row['SGUFCONSREG'])?$row['SGUFCONSREG']:null;

                $row['NRCERTRESEPES'] = isset($row['NRCERTRESEPES'])?$row['NRCERTRESEPES']:null;

                $row['DTCERTRESEPES'] = isset($row['DTCERTRESEPES'])?$row['DTCERTRESEPES']:null;
                
                $this->objects[] = $this->finalizarProcessoService->salvarPessoaH($row);

                
            }
            self::salvarContaBancaria($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarContaBancaria (DTO\Request\DataSet $request, DTO\Response $response){
        try{
            foreach ($request->getDataSet()->getRows() as &$row) {

                $row['NRTPCONTCORR'] = isset($row['NRTPCONTCORR'])?$row['NRTPCONTCORR']:2;

                
                $row['NRCONTCORRPARC'] = isset($row['NRCONTCORRPARC'])?$row['NRCONTCORRPARC']:\HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'CONTCORRPARC', 1, 12, true);
                
                $row['CDREDUCONT'] = isset($row['CDREDUCONT'])?$row['CDREDUCONT']:null;
                
                if($row['CDREDUCONT'] == ''){
                    $row['CDREDUCONT'] = null;
                }

                $row['NRORGULTATU'] = isset($row['NRORGULTATU'])?$row['NRORGULTATU']:1;

                $row['CDOPERULTATU'] = isset($row['CDOPERULTATU'])?$row['CDOPERULTATU']:"1";

                $row['IDATIVO'] = isset($row['IDATIVO'])?$row['IDATIVO']:'S';
                
                $this->objects[] = $this->finalizarProcessoService->salvarContaBancaria($row);
            }
            self::salvarOperador($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    function salvarOperador (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) { 

                $row['CDOPERADOR'] = (string)$this->operadorService->getNextId();
                $row['CDOPERADOR'] = str_pad($row['CDOPERADOR'], 12, "0", STR_PAD_LEFT);


                $row['DTNASCIMENTO'] = isset($row['DTNASCIMENTO'])?$row['DTNASCIMENTO']:$row['DTNASCPESSOA'];

                $row['NMACESSO'] = isset($row['NMACESSO'])?$row['NMACESSO']:$row['DSEMAILOPER'];

                $row['IDCADPRPROCEORE'] = isset($row['IDCADPRPROCEORE'])?$row['IDCADPRPROCEORE']:'N';

                $row['IDLIGEXTOPER'] = isset($row['IDLIGEXTOPER'])?$row['IDLIGEXTOPER']:'N';

                $row['IDSENHVARDIA'] = isset($row['IDSENHVARDIA'])?$row['IDSENHVARDIA']:'N';

                $row['IDOPERMASTER'] = isset($row['IDOPERMASTER'])?$row['IDOPERMASTER']:'N';

                $row['IDOPERACESSO'] = isset($row['IDOPERACESSO'])?$row['IDOPERACESSO']:'000000000000000000000000000000';

                $row['IDOPERATIVO'] = isset($row['IDOPERATIVO'])?$row['IDOPERATIVO']:'A';

                $row['IDSTATUSENHA'] = isset($row['IDSTATUSENHA'])?$row['IDSTATUSENHA']:'A';

                $row['IDATUOPERADOR'] = isset($row['IDATUOPERADOR'])?$row['IDATUOPERADOR']:'S';

                $row['IDCADPRAPROVORE'] = isset($row['IDCADPRAPROVORE'])?$row['IDCADPRAPROVORE']:'N';

                $row['DTULTATUOPER'] = isset($row['DTULTATUOPER'])?$row['DTULTATUOPER']:date('d/m/Y');

                $row['NRORGTRAB'] = isset($row['NRORGTRAB'])?$row['NRORGTRAB']:$row['NRORG'];

                $row['CDFUNC'] = isset($row['CDFUNC'])?$row['CDFUNC']:'0003';
                
                $this->objects[] = $this->finalizarProcessoService->salvarOperador($row);
            }
            self::salvarVinculoM($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarVinculoM (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) { 

                $row['NRVINCULOM'] = isset($row['NRVINCULOM'])?$row['NRVINCULOM']:$this->vinculoServices->getNrVinculoM($row['NRORG']);
                $row['DTRESCISAOVINC'] = isset($row['DTRESCISAOVINC'])?$row['DTRESCISAOVINC']:null;
                $row['CDMATRICULA'] = isset($row['CDMATRICULA'])?$row['CDMATRICULA']:null;
                $row['NRVINCULOEMPREG'] = isset($row['NRVINCULOEMPREG'])?$row['NRVINCULOEMPREG']:1;
                $row['NRTPDEMISSAO'] = isset($row['NRTPDEMISSAO'])?$row['NRTPDEMISSAO']:null;
                $row['NMVINCULOM'] = isset($row['NMVINCULOM'])?$row['NMVINCULOM']:$row['NMOPERADOR'];
                $row['IDSEGDESEMPVINC'] = isset($row['IDSEGDESEMPVINC'])?$row['IDSEGDESEMPVINC']:'N';
                $row['IDSEGDESEMPVINC'] = isset($row['IDSEGDESEMPVINC'])?$row['IDSEGDESEMPVINC']:'N';
                $row['DTPRIMADMISSAO'] = isset($row['DTPRIMADMISSAO'])?$row['DTPRIMADMISSAO']:$row['DTADMISSAOVINC'];
                $row['NRDIASCONTRATOEXP'] = isset($row['NRDIASCONTRATOEXP'])?$row['NRDIASCONTRATOEXP']:null;
                $row['NRDIASCONTRATOEXPPRO'] = isset($row['NRDIASCONTRATOEXPPRO'])?$row['NRDIASCONTRATOEXPPRO']:null;
                $row['DTVENCCONTREXPER'] = isset($row['DTVENCCONTREXPER'])?$row['DTVENCCONTREXPER']:null;
                $row['NRCLAUSASSECURAT'] = isset($row['NRCLAUSASSECURAT'])?$row['NRCLAUSASSECURAT']:null;
                $row['DTOPCAOFGTS'] = isset($row['DTOPCAOFGTS'])?$row['DTOPCAOFGTS']:null;

                
                $this->objects[] = $this->finalizarProcessoService->salvarVinculoM($row);
                
                $this->altebancohoras = $this->finalizarProcessoService->getAltebancohoras($row['NRORG'],$row['NRVINCULOM']);
                $this->progocorrencia = $this->finalizarProcessoService->getProgocorrencia($row['NRORG'],$row['NRVINCULOM']);
                
                $row['NRPARCNEGOCIOCAND'] = isset($row['NRPARCNEGOCIOCAND']) ? $row['NRPARCNEGOCIOCAND']:$row['NRPARCNEGOCIO_ANTIGO'];
                $this->objPartProcesso = $this->finalizarProcessoService->atualizaPartProcesso($row);
            }   
            self::salvarMovimentacao($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarMovimentacao (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) { 
                
                $row['IDATUALIZAACERTO'] = isset($row['IDATUALIZAACERTO'])?$row['IDATUALIZAACERTO']:0;

                if(array_key_exists('NRTIPOTRANSFER_LEGAL', $row)){
                    $row['__is_new'] = true;
                    $row['NRTIPOTRANSFER'] = $row['NRTIPOTRANSFER_LEGAL'];

                    $row['NRMOVIMENTACAO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_MOVIMENTACAO', 1, 12, true);

                    if(array_key_exists('NMTIPOTRANSFER_LEGAL', $row))
                        $row['NMTIPOTRANSFER'] = $row['NMTIPOTRANSFER_LEGAL'];

                    if(array_key_exists('NRESTRUTURAM_LEGAL', $row)){
                        $row['NRESTRUTURAM'] = $row['NRESTRUTURAM_LEGAL'];
                        $row['NRESTRUTLEGAL'] = $row['NRESTRUTURAM_LEGAL'];
                    }

                    if(array_key_exists('NRTIPOESTRUTURA_LEGAL', $row))
                        $row['NRTIPOESTRUTURA'] = $row['NRTIPOESTRUTURA_LEGAL'];
                    $this->objects[] = $this->finalizarProcessoService->salvarMovimentacao($row);
                }

                if(array_key_exists('NRTIPOTRANSFER_GEREN', $row)){
                    $row['__is_new'] = true;
                    $row['NRTIPOTRANSFER'] = $row['NRTIPOTRANSFER_GEREN'];

                    $row['NRMOVIMENTACAO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_MOVIMENTACAO', 1, 12, true);

                    if(array_key_exists('NMTIPOTRANSFER_GEREN', $row))
                        $row['NMTIPOTRANSFER'] = $row['NMTIPOTRANSFER_GEREN'];

                    if(array_key_exists('NRESTRUTURAM_GEREN', $row)){
                        $row['NRESTRUTURAM'] = $row['NRESTRUTURAM_GEREN'];
                        $row['NRESTRUTGEREN'] = $row['NRESTRUTURAM_GEREN'];
                    }

                    if(array_key_exists('NRTIPOESTRUTURA_GEREN', $row))
                        $row['NRTIPOESTRUTURA'] = $row['NRTIPOESTRUTURA_GEREN'];

                    $this->objects[] = $this->finalizarProcessoService->salvarMovimentacao($row);
                }

                if(array_key_exists('NRTIPOTRANSFER_SINDICAL', $row)){
                    $row['__is_new'] = true;
                    $row['NRTIPOTRANSFER'] = $row['NRTIPOTRANSFER_SINDICAL'];

                    $row['NRMOVIMENTACAO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_MOVIMENTACAO', 1, 12, true);

                    if(array_key_exists('NMTIPOTRANSFER_SINDICAL', $row))
                        $row['NMTIPOTRANSFER'] = $row['NMTIPOTRANSFER_SINDICAL'];

                    if(array_key_exists('NRESTRUTURAM_SINDICAL', $row)){
                        $row['NRESTRUTURAM'] = $row['NRESTRUTURAM_SINDICAL'];
                        $row['NRESTRUTSIND'] = $row['NRESTRUTURAM_SINDICAL'];
                    }

                    if(array_key_exists('NRTIPOESTRUTURA_SINDICAL', $row))
                        $row['NRTIPOESTRUTURA'] = $row['NRTIPOESTRUTURA_SINDICAL'];

                    $this->objects[] = $this->finalizarProcessoService->salvarMovimentacao($row);
                }
            }
            self::salvarVinculoH($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarVinculoH (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) { 
                
                $row['NRVINCULOH'] = isset($row['NRVINCULOH'])?$row['NRVINCULOH']:$this->vinculoServices->getNrVinculoH($row['NRORG']);

                $row['NRCARGO'] = isset($row['NRCARGO'])?$row['NRCARGO']:$row['NROCUPACAOM'];

                $row['NRFUNCAO'] = isset($row['NRFUNCAO'])?$row['NRFUNCAO']:$row['NROCUPACAOM'];

                $row['NRESCALATRABM'] = isset($row['NRESCALATRABM'])?$row['NRESCALATRABM']:null;

                $row['IDCONTRIBUISIND'] = isset($row['IDCONTRIBUISIND'])?$row['IDCONTRIBUISIND']:'SEMPRE';

                $row['DTBASEFERIAS'] = isset($row['DTBASEFERIAS'])?$row['DTBASEFERIAS']:$row['DTBASEFERIAS'];

                $row['IDREMUNERACAO'] = isset($row['IDREMUNERACAO'])?$row['IDREMUNERACAO']:$row['IDREMUNERACAO'];

                $row['IDTPPAGAMENTO'] = isset($row['IDTPPAGAMENTO'])?$row['IDTPPAGAMENTO']:$row['IDTPPAGAMENTO'];

                $row['NRESTRUTLEGAL'] = isset($row['NRESTRUTLEGAL'])?$row['NRESTRUTLEGAL']:null;

                $row['NRTPMODALIDSAL'] = isset($row['NRTPMODALIDSAL'])?$row['NRTPMODALIDSAL']:1;

                $row['IDMULTVINC'] = isset($row['IDMULTVINC'])?$row['IDMULTVINC']:'UNICO';

                $row['CONFIDENCIAL'] = isset($row['CONFIDENCIAL'])?$row['CONFIDENCIAL']:'N';

                $row['NRTPREGIMEPREV'] = isset($row['NRTPREGIMEPREV'])?$row['NRTPREGIMEPREV']:1;

                $row['NRESTRUTGEREN'] = isset($row['NRESTRUTGEREN'])?$row['NRESTRUTGEREN']:null;
                $row['DTFIMCONTRDETERMIN'] = isset($row['DTFIMCONTRDETERMIN'])?$row['DTFIMCONTRDETERMIN']:null;
            }
            $this->objects[] = $this->finalizarProcessoService->salvarVinculoH($row);
            self::salvarDependentes($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarDependentes(DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as $row) {
                if(array_key_exists('DEPENDENTES', $row) && !empty($row['DEPENDENTES'])){
                    foreach($row['DEPENDENTES'] as &$rows){
                        // SALVAR PARCNEGOCIO
                        $dtmescompetencia = str_split(DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString($row['DTADMISSAOVINC']))->__toString(), 10);
                        $dtmescompetencia = $dtmescompetencia[0];

                        $rows['NRPARCNEGOCIO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'PARCNEGOCIO', 1, 12, true);
                        $rows['NMPESSOA'] = $this->util->removeCaracteresEspeciais($rows['NMPESSOA']);
                        $rows['NMPESSOA'] = strtoupper($rows['NMPESSOA']);
                        
                        $rows['NMPRINCIPALPARC'] = isset($rows['NMPRINCIPALPARC'])?$rows['NMPRINCIPALPARC']:$rows['NMPESSOA'];
                        
                        $rows['NMSECUNDARIPARC'] = isset($rows['NMSECUNDARIPARC'])?$rows['NMSECUNDARIPARC']:$rows['NMPESSOA'];
                        
                        $rows['DTNASCIFUNDPARC'] = isset($rows['DTNASCIFUNDPARC'])?$rows['DTNASCIFUNDPARC']:$rows['DTNASCPESSOA'];
                        
                        $rows['IDATIVO'] = isset($rows['IDATIVO'])?$rows['IDATIVO']:'S';

                        $rows['NRINSCRICAOPARC'] = null;

                        $rows['CDTIPOPARCPRINCIPAL'] = isset($rows['CDTIPOPARCPRINCIPAL'])?$rows['CDTIPOPARCPRINCIPAL']:'PESSOA';
                        
                        $rows['IDPESSOAFISICA'] = isset($rows['IDPESSOAFISICA'])?$rows['IDPESSOAFISICA']:'S';
                        
                        $rows['IDINSTITUICAO'] = isset($rows['IDINSTITUICAO'])?$rows['IDINSTITUICAO']:'N';
                        
                        $rows['IDPARCFUNDIDO'] = isset($rows['IDPARCFUNDIDO'])?$rows['IDPARCFUNDIDO']:'N';
                        
                        $rows['DTINCLUSAO'] = isset($rows['DTINCLUSAO'])?$rows['DTINCLUSAO']:date('d/m/Y');
                        
                        $rows['NRORG'] = isset($rows['NRORG'])?$rows['NRORG']:$row['NRORG'];
                        
                        $rows['CDOPERINCLUSAO'] = isset($rows['CDOPERINCLUSAO'])?$rows['CDOPERINCLUSAO']:$this->hcmParameters->getCdoperador();


                        $this->objects[] = $this->finalizarProcessoService->salvaParcNegocio($rows);
                        
                        //SALVAR PARCERIA
                        $rows['NRPARCERIA'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'PARCERIA', 1, 12, true);
                        
                        $rows['CDTIPOPARCEIRO'] = isset($rows['CDTIPOPARCEIRO'])?$rows['CDTIPOPARCEIRO']:'PESSOA';
                        
                        $rows['DTULTATU'] = isset($rows['DTULTATU'])?$rows['DTULTATU']:$rows['DTINCLUSAO'];
                        
                        $rows['NRORGINCLUSAO'] = isset($rows['NRORGINCLUSAO'])?$rows['NRORGINCLUSAO']:1;
                       
                        $rows['NRORGULTATU'] = isset($rows['NRORGULTATU'])?$rows['NRORGULTATU']:1;
                       
                        $rows['CDOPERINCLUSAO'] = isset($rows['CDOPERINCLUSAO'])?$rows['CDOPERINCLUSAO']:$row['CDOPERADOR_LOG'];
                       
                        $rows['CDOPERULTATU'] = isset($rows['CDOPERULTATU'])?$rows['CDOPERULTATU']:$row['CDOPERADOR_LOG'];

                        $this->objects[] = $this->finalizarProcessoService->salvarParceria($rows);

                        //SALVAR GPE_PESSOA
                        $rows['NRPESSOA'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_PESSOA', 1, 12, true);

                        $this->objects[] = $this->finalizarProcessoService->salvarPessoa($rows);

                        //SALVAR GPE_PESSOAH
                        list($primeiroNome, $meioNome, $ultimoNome) = self::decompoeNomePessoa($rows['NMPESSOA']);
                        $dtmescompetencia = str_split(DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString($row['DTADMISSAOVINC']))->__toString(), 10);
                        $dtmescompetencia = $dtmescompetencia[0];

                        $rows['DTMESCOMPETENC'] = isset($rows['DTMESCOMPETENC'])?$rows['DTMESCOMPETENC']:$dtmescompetencia;
                        
                        $rows['DSPRINOMEPESS'] = isset($rows['DSPRINOMEPESS'])?$rows['DSPRINOMEPESS']:$primeiroNome; 
                        
                        $rows['DSULTNOMEPESS'] = isset($rows['DSULTNOMEPESS'])?$rows['DSULTNOMEPESS']:$ultimoNome;
                        
                        $rows['DSNOMEMEIOPESS'] = isset($rows['DSNOMEMEIOPESS'])?$rows['DSNOMEMEIOPESS']:$meioNome;

                        $rows['NRPESSOAH'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_PESSOAH', 1, 12, true);

                        $rows['NRNACIONALID'] = isset($rows['NRNACIONALID'])?$rows['NRNACIONALID']:$row['NRNACIONALIDADE'];
                        
                        $rows['DTCASAPESSOA'] = isset($rows['DTCASAPESSOA'])?$rows['DTCASAPESSOA']:null;
                        
                        $rows['NRCERTCASAPES'] = isset($rows['NRCERTCASAPES'])?$rows['NRCERTCASAPES']:null;
                        
                        $rows['NRRACAPESSOA'] = isset($rows['NRRACAPESSOA'])?$rows['NRRACAPESSOA']:null;
                        
                        $rows['NRRGPESSOA'] = isset($rows['NRRGPESSOA'])?$rows['NRRGPESSOA']:null;
                        
                        $rows['CDEXRGPESSOA'] = isset($rows['CDEXRGPESSOA'])?$rows['CDEXRGPESSOA']:null;
                        
                        $rows['DTEXRGPESSOA'] = isset($rows['DTEXRGPESSOA'])?$rows['DTEXRGPESSOA']:null;
                        
                        $rows['DSLOCALEXRGPES'] = isset($rows['DSLOCALEXRGPES'])?$rows['DSLOCALEXRGPES']:null;
                        
                        $rows['SGUFRGPESSOA'] = isset($rows['SGUFRGPESSOA'])?$rows['SGUFRGPESSOA']:null;
                        
                        $rows['NRTITUELEIPES'] = isset($rows['NRTITUELEIPES'])?$rows['NRTITUELEIPES']:null;
                        
                        $rows['NRZONAELEIPES'] = isset($rows['NRZONAELEIPES'])?$rows['NRZONAELEIPES']:null;
                        
                        $rows['NRSECAELEIPES'] = isset($rows['NRSECAELEIPES'])?$rows['NRSECAELEIPES']:null;
                        
                        $rows['IDISENTITUELEI'] = isset($rows['IDISENTITUELEI'])?$rows['IDISENTITUELEI']:null;
                        
                        $rows['NRCARTHABPES'] = isset($rows['NRCARTHABPES'])?$rows['NRCARTHABPES']:null;
                        
                        $rows['DSCATEGHABCART'] = isset($rows['DSCATEGHABCART'])?$rows['DSCATEGHABCART']:null;
                        
                        $rows['DTVALHABCARTPES'] = isset($rows['DTVALHABCARTPES'])?substr($rows['DTVALHABCARTPES'],0,10):null;
                        
                        $rows['NRCTPSPESSOA'] = isset($rows['NRCTPSPESSOA'])?$rows['NRCTPSPESSOA']:null;
                        
                        $rows['NRSERIECTPSPES'] = isset($rows['NRSERIECTPSPES'])?$rows['NRSERIECTPSPES']:null;
                        
                        $rows['DTCTPSPESSOA'] = isset($rows['DTCTPSPESSOA'])?$rows['DTCTPSPESSOA']:null;
                        
                        $rows['SGUFCTPSPES'] = isset($rows['SGUFCTPSPES'])?$rows['SGUFCTPSPES']:null;
                        
                        $rows['NRPISPASEPPES'] = isset($rows['NRPISPASEPPES'])?$rows['NRPISPASEPPES']:null;
                        
                        $rows['DTINSCPISPASEP'] = isset($rows['DTINSCPISPASEP'])?$rows['DTINSCPISPASEP']:null;
                        
                        $rows['NRREGCTPSPES'] = isset($rows['NRREGCTPSPES'])?$rows['NRREGCTPSPES']:null;
                        
                        $rows['NRINSCRCONSREG'] = isset($rows['NRINSCRCONSREG'])?$rows['NRINSCRCONSREG']:null;
                        
                        $rows['DTEXCONSREG'] = isset($rows['DTEXCONSREG'])?$rows['DTEXCONSREG']:null;
                        
                        $rows['SGUFCONSREG'] = isset($rows['SGUFCONSREG'])?$rows['SGUFCONSREG']:null;
                        
                        $rows['NRCERTRESEPES'] = isset($rows['NRCERTRESEPES'])?$rows['NRCERTRESEPES']:null;
                        
                        $rows['DTCERTRESEPES'] = isset($rows['DTCERTRESEPES'])?$rows['DTCERTRESEPES']:null;
                        
                        $rows['CDPAIS'] = isset($rows['CDPAIS'])?$rows['CDPAIS']:null;
                        
                        $rows['SGESTADO'] = isset($rows['SGESTADO'])?$rows['SGESTADO']:null;
                        
                        $rows['CDMUNICIPIO'] = isset($rows['CDMUNICIPIO'])?$rows['CDMUNICIPIO']:null;
                        
                        $rows['NRGRAUINSTR'] = isset($rows['NRGRAUINSTR'])?$rows['NRGRAUINSTR']:null;
                        
                        $rows['NRNACIONALID'] = isset($rows['NRNACIONALID'])?$rows['NRNACIONALID']:null;
                        
                        $rows['NRCONDFISPES'] = isset($rows['NRCONDFISPES'])?$rows['NRCONDFISPES']:null;
                        
                        $rows['NRCPFPESSOA'] = isset($rows['NRCPFPESSOA'])?$rows['NRCPFPESSOA']:null;
                        
                        $rows['IDPOSSUIFILHO'] = isset($rows['IDPOSSUIFILHO'])?$rows['IDPOSSUIFILHO']:null;
        
                        $rows['NRIDADEFILHO'] = isset($rows['NRIDADEFILHO'])?$rows['NRIDADEFILHO']:null;
                        $this->objects[] = $this->finalizarProcessoService->salvarPessoaH($rows);

                        //SALVAR RELACIONAPARC
                        $rows['NRRELACIONAPARC'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'RELACIONAPARC', 1, 12, true);
                        if(!array_key_exists('NRPARCNEGRELAC', $rows)){
                           $rows['NRPARCNEGRELAC'] = $rows['NRPARCNEGOCIO'];
                           
                           $rows['NRPARCNEGOCIO']  = $row['NRPARCNEGOCIO'];
                        }

                        $rows['NRPARCTESTE'] = isset($rows['NRPARCTESTE'])?$rows['NRPARCTESTE']:null;
                        
                        $rows['CDCARGO'] = isset($rows['CDCARGO'])?$rows['CDCARGO']:null;
                        
                        $rows['NRTIPORELACIONA'] = isset($rows['NRTIPORELACIONA'])?$rows['NRTIPORELACIONA']:null;
                        
                        $this->objects[] = $this->finalizarProcessoService->salvarRelacionamento($rows);
                        //SALVAR FPA_DEPVINCULO
                        if(array_key_exists('NRTIPODEPENDE', $rows)){
                            if(is_array($rows['NRTIPODEPENDE'])){
                                foreach ($rows['NRTIPODEPENDE'] as $nrtipodepende){
                                    $rows['NRDEPVINCULO'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'FPA_DEPVINCULO', 1, 12, true);
                                    
                                    $rows['NRVINCULOM'] = isset($rows['NRVINCULOM'])?$rows['NRVINCULOM']:$row['NRVINCULOM'];
                                    
                                    $rows['NROUTRVINCULOM'] = isset($rows['NROUTRVINCULOM'])?$rows['NROUTRVINCULOM']:11;
                                    
                                    $rows['NRORGULTATU'] = isset($rows['NRORGULTATU'])?$rows['NRORGULTATU']:1;
                                    
                                    $rows['CDOPERULTATU'] = isset($rows['CDOPERULTATU'])?$rows['CDOPERULTATU']:1;
                                    
                                    $rows['NRTIPODEPENDE'] = $nrtipodepende;
                                    $this->objects[] = $this->finalizarProcessoService->salvarDependentes($rows);
                                }
                            }
                        }
                    }
                }
            }
            self::salvarOcupacao($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarOcupacao (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) { 
                
                $row['__is_new'] = true;

                $row['NRALTEOCUPACAO'] = isset($row['NRALTEOCUPACAO'])?$row['NRALTEOCUPACAO']:\HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_ALTEOCUPACAO', 1, 12, true);
                   
                $row['DTFIMOCUPACAO'] = isset($row['DTFIMOCUPACAO'])?$row['DTFIMOCUPACAO']:null;
            
                $this->objects[] = $this->finalizarProcessoService->salvarOcupacao($row);
            }
            self::salvarEscala($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarEscala (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) { 
                
                $row['__is_new'] = true;

                $row['NRALTEESCALA'] = isset($row['NRALTEESCALA'])?$row['NRALTEESCALA']:\HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_ALTEESCALA', 1, 12, true);
                   
                $row['DTFIMESCALA'] = isset($row['DTFIMESCALA'])?$row['DTFIMESCALA']:null;

                $row['NRHORDIAM'] = null;
                
                $row['NRTURNO'] = isset($row['NRTURNO'])?$row['NRTURNO']:null;

                if(!array_key_exists('QTHRLIMITESEPHEXTRA', $row))
                    $row['QTHRLIMITESEPHEXTRA'] = null;
                else {
                    $row['QTHRLIMITESEPHEXTRA'] = str_replace(":", "", $row['QTHRLIMITESEPHEXTRA']);
                }
                
                $this->objects[] = $this->finalizarProcessoService->salvarEscala($row);

            }
            self::salvarSituacaoFuncionario($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarSituacaoFuncionario (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) { 
                
                $row['NRALTESITUFUNC'] = isset($row['NRALTESITUFUNC'])?$row['NRALTESITUFUNC']:\HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_ALTESITUFUNC', 1, 12, true);
            
                $this->objects[] = $this->finalizarProcessoService->salvarSituacaoFuncionario($row);
            }
            self::salvarSalario($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarSalario (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) {
                
                $row['NRALTESALARIO'] = isset($row['NRALTESALARIO'])?$row['NRALTESALARIO']:\HCM\Util\NovoCodigo::geraCodigo($row['NRORG'], 'GPE_ALTESALARIO', 1, 12, true);

                $row['NROCORRENCIA'] = isset($row['NROCORRENCIA'])?$row['NROCORRENCIA']:1;

                if(array_key_exists('CDTIPOSALARIO', $row))
                    $row['IDTPSALARIO'] = $row['CDTIPOSALARIO'];

                if(array_key_exists('VRSALARIO', $row))
                    $row['VRSALARIO'] = $this->validaValorMonetario($row['VRSALARIO']);
                
                $this->objects[] = $this->finalizarProcessoService->salvarSalario($row);

            }
            self::salvarEndereco($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarEndereco (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach($request->getDataSet()->getRows() as &$row) {
                $this->objects = array_merge($this->objects,$this->finalizarProcessoService->salvarEndereco($row));
            }
            
            self::salvarFormaComunicacao($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarFormaComunicacao (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as &$row) {
                $this->objects = array_merge($this->objects,$this->finalizarProcessoService->salvarFormaComunicacao($row));
            }
            
            self::salvarFormacao($request, $response);
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function salvarFormacao (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            foreach($request->getDataSet()->getRows() as $row) {
                if(array_key_exists('FORMACAO', $row) && !empty($row['FORMACAO'])){
                    foreach($row['FORMACAO'] as &$rows){
                        $rows["NRPARCNEGOCIO"] = $row['NRPARCNEGOCIO'];
                        $rows["NRORG"] = $row['NRORG'];
                        $rows["CDOPERINCLUSAO"]= $row['CDOPERINCLUSAO'];
                        $rows["DTINCLUSAO"]= $row['DTINCLUSAO'];
                        $rows["CDIDIOMA"] = isset($rows["CDIDIOMA"])?$rows["CDIDIOMA"]:null;
                        $rows["CDOPERULTATU"] = isset($rows["CDOPERULTATU"])?$rows["CDOPERULTATU"]:null;
                        $rows["DES_AREAFORMACAO_NRORG"] = isset($rows["DES_AREAFORMACAO_NRORG"])?$rows["DES_AREAFORMACAO_NRORG"]:null;
                        $rows["DSCURSO"] = isset($rows["DSCURSO"])?$rows["DSCURSO"]:null;
                        $rows["DSOBSERVACAO"] = isset($rows["DSOBSERVACAO"])?$rows["DSOBSERVACAO"]:null;
                        $rows["DTFIM"] = isset($rows["DTFIM"])?$rows["DTFIM"]:null;
                        $rows["DSINSTITUICAO"] = isset($rows["DSINSTITUICAO"])?$rows["DSINSTITUICAO"]:null;
                        $rows["DTINICIO"] = isset($rows["DTINICIO"])?$rows["DTINICIO"]:null;
                        $rows["DTULTATU"] = isset($rows["DTULTATU"])?$rows["DTULTATU"]:null;
                        $rows["IDNVIDIOMA"] = isset($rows["IDNVIDIOMA"])?$rows["IDNVIDIOMA"]:null;
                        $rows["NRAREAFORMACAO"] = isset($rows["NRAREAFORMACAO"])?$rows["NRAREAFORMACAO"]:null;
                        $rows["NRCARGAHORARIA"] = isset($rows["NRCARGAHORARIA"])?$rows["NRCARGAHORARIA"]:null;
                        $rows["NRCURSO"] = isset($rows["NRCURSO"])?$rows["NRCURSO"]:null;
                        $rows["NRFORMACAO"] = isset($rows["NRFORMACAO"])?$rows["NRFORMACAO"]:null;
                        $rows["DSANDAMENTOCURSO"] = isset($rows["DSANDAMENTOCURSO"])?$rows["DSANDAMENTOCURSO"]:null;
                        $rows["NRINSTITUICAOPARC"] = isset($rows["NRINSTITUICAOPARC"])?$rows["NRINSTITUICAOPARC"]:null;
                        $rows["NRTIPOFORMACAO"] = isset($rows["NRTIPOFORMACAO"])?$rows["NRTIPOFORMACAO"]:null;
                        
                        $this->objects[] = $this->finalizarProcessoService->salvarFormacao($rows);

                    }
                }
            }
            
            $response->addNotification(new DTO\Response\Notification('finalizarProcesso', DTO\Response\Notification::TYPE_SUCCESS));
        } catch(\Exception $e) {
            self::trataExcecao();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function trataExcecao() {
        try {
            if(!empty($this->altebancohoras))
                $this->finalizarProcessoService->deleteAltebancohoras($this->altebancohoras);
            if(!empty($this->progocorrencia))
                $this->finalizarProcessoService->deleteProgocorrencia($this->progocorrencia);
            if(!empty($this->objPartProcesso))
                $this->finalizarProcessoService->atualizaPartProcesso($this->objPartProcesso[0]);
            if(!empty($this->objects))
                $this->finalizarProcessoService->removeObjetos($this->objects);
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public static function decompoeNomePessoa($nmpessoa){

        $arrayNmpessoa = explode(' ', $nmpessoa);
        $nomeMeio      = '';

        $primeiroNome = $arrayNmpessoa[0];
        for ($i = 1; $i < count($arrayNmpessoa) - 1; $i++) {
            $nomeMeio .= ' ' . $arrayNmpessoa[$i];
            $nomeMeio = trim($nomeMeio);
        }
        $ultimoNome = $arrayNmpessoa[count($arrayNmpessoa) - 1];
        $nomeMeio   = ($nomeMeio) ? : $ultimoNome;
        return array($primeiroNome, $nomeMeio, $ultimoNome);
    }

    public function validaValorMonetario($valor){
        if(!empty($valor)){    
            $valor = str_replace('.','',$valor);
            $valor = str_replace(',','.',$valor);
            return $valor;
        }

        return null;           
    }
}