<?php

namespace HCM\FPA\Calculos\Fechamento;

use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;
use HCM\Util\FPA;
use HCM\Util\TkDI;
use HCM\Util\MsgCalculo;
use HCM\FPA\Entity\FpaitecalcfolhaEntity;
use HCM\FPA\Entity\FpatipoassoceveEntity;
use HCM\FPA\Entity\FpatipomovimentEntity;
use HCM\FPA\Entity\FpaeventohEntity;
use HCM\Geral\Entity\GpevinculomEntity;


class Fechamento{

    private $_nrorg;
    private $_nr_tipo_calculo;
    private $_mes_competencia;

    private $_itens_calculo;
    private $_itens_periodo_seguinte;
    private $_eventom;
    private $_itens_decimo_terceiro;
    private $_valorCredito13;	
	
    public function __construct($entityManager, $hcmParameters, $nr_tipo_calculo){
        
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->_nrorg = $hcmParameters->getNrorgTrabalho();
        $this->_mes_competencia = DateUtil::getDataDeString($hcmParameters->getDtCompetencia());
        $this->_mes_competencia_int = $this->_mes_competencia->format('m');
        $this->_nr_tipo_calculo = $nr_tipo_calculo;
        
        $this->_itens_periodo_seguinte = new FpaitecalcfolhaEntity($entityManager, $hcmParameters);
        $this->_itens_decimo_terceiro  = new FpaitecalcfolhaEntity($entityManager, $hcmParameters);
        $this->_valorCredito13 = 0;				

        $this->_eventom = TkDI::getContainer()->eventom;
    }

    public function fechar(
        $vinculo, $itensCalculo, $tp_calc_mov_seg
    ) {

        if ($tp_calc_mov_seg->retornaItensCalculo($vinculo) === false) {
            return;
        }

        $this->_itens_calculo = $itensCalculo;

        try{
            $obj_tp_calc_mov_seg = current(
                $tp_calc_mov_seg->retornaPosicaoTpMov($tp_calc_mov_seg->retornaTpMovPrincipal(), 1)
            );
            $this->_itens_periodo_seguinte =  $obj_tp_calc_mov_seg->getInstancia();
			
            $itens = $this->_itens_periodo_seguinte->getItems();
            foreach ($itens as $item) {
                if ((FpatipoassoceveEntity::ASSOC_LIQUIDO == $item->getNreventom()) or (FpatipoassoceveEntity::ASSOC_LIQUIDO_RESCISAO == $item->getNreventom())){
                    return;
                }
            }					
        } catch(Exception $e){
            $message = $e->getMessage().' - Principal FECHAMENTO.PHP';
            throw new Exception($message);
        }

       try{
            $obj_tp_calc_13 = current($tp_calc_mov_seg->retornaPosicaoTpMov(FpatipomovimentEntity::TP_MOV_13SAL));
            $this->_itens_decimo_terceiro =  $obj_tp_calc_13->getInstancia();
            $itens = $this->_itens_decimo_terceiro->getItems();

            foreach ($itens as $item) {
                if (FpatipoassoceveEntity::ASSOC_ARREDONDAM_SAL_CR == $item->getNreventom()) {
                    $this->_valorCredito13 = $item->getVreventofolha();
                }
            }

        } catch(Exception $e){
            $message = $e->getMessage().' - 13º SALARIO FECHAMENTO.PHP';
            throw new Exception($message);
        }		
        $this->projetaPeriodoSeguinte($vinculo);

        if ( (int)$this->_mes_competencia_int == 12) TkDI::getContainer()->vinculom->projetaVinculoFimAno($vinculo->historico,$this->_mes_competencia);


    }

    public function projetaPeriodoSeguinte($vinculo){

        $itens = $this->_itens_calculo->getItems();
        $fechado = false;
        foreach ($itens as $item) {
            $projeta = false;
            $evento = $this->_eventom->retornaEvento($item->getNreventom());
            $novo_contador = $item->getQtocorproxperi();
            if ($novo_contador > 1) {
                $projeta = true;
                $novo_contador--;
            }
            if($item->getNreventom()==FpatipoassoceveEntity::ASSOC_LIQUIDO){
                $fechado=true;
            }
            $novo_mes_ocorrencia = DateUtil::getDataDeString($item->getDtocorrencia());
            $mes_competencia_aux = DateUtil::setDay($item->getDtocorrencia(), 1);
            
            if ($mes_competencia_aux > $this->_mes_competencia) {
                $nr_novo_evento = $evento->historico->getNreventotransf();
                if (empty($nr_novo_evento) === false) {
                    $projeta = true;
                }
            } else {
                $novo_mes_ocorrencia = DateUtil::adicionaIntervalo($novo_mes_ocorrencia, 1, DateUtil::MES);				
			    $nr_novo_evento = $evento->historico->getNreventotransf();
                if (empty($nr_novo_evento) === false) {
                    $projeta = true;
                }			  				 
            }
            
            if ($evento->historico->getIdtipoocorreven() === FpaeventohEntity::IDTIPOOCORREVEN_FIXA) {
                $projeta = true;
            }

            if ($projeta === true) {
                $nr_novo_evento = $evento->historico->getNreventotransf();
                if (empty($nr_novo_evento) === true) {
                    $novo_evento = $evento;
                } else {
                    $novo_evento = $this->_eventom->retornaEvento($nr_novo_evento);
                }

                if ($evento->historico->getIdzeraevenfecha() === 'S') {
                    $novo_valor = 0;
                } else {
                    if (FpatipoassoceveEntity::ASSOC_ARREDONDAM_SAL_CR == $evento->historico->getNreventom()) {
                        if ($this->_valorCredito13 > 0) {					
                            $novo_valor = $item->getVreventofolha() + $this->_valorCredito13;
                        } else {
                            $novo_valor = $item->getVreventofolha();
                        }
                    }	else {
                        $novo_valor = $item->getVreventofolha();
                    }
                }
                $nova_referencia = $item->getVrreffolha();
                
                $this->_itens_periodo_seguinte->geraEvento(
                    $novo_evento, $novo_mes_ocorrencia, $novo_valor, $nova_referencia, $novo_contador
                );
            }
        }
        //BORBA
        if($fechado==true){
            $eventofecha = $this->_eventom->retornaEvento(FpatipoassoceveEntity::ASSOC_FECHADO);
            $this->_itens_calculo->geraEvento($eventofecha, null, 0, 0, 1);
            $this->fechaMovimentos($vinculo);
        }else{
            //@todo MsgCalculo
            MsgCalculo::getInstance()->adicionaMensagem('Fechamento não realizado para o vínculo pois não possui gravação definitiva.',MsgCalculo::ALERTA);
        }
    }
    
    public function fechaMovimentos($vinculo){
        
        //Ferias
        $calc_Ferias = $this->entityManager->getRepository(Repositories::FPA_CALCULOFOLHA)->retornaCalculoFolha(
            $this->_nrorg, FpatipomovimentEntity::TP_MOV_FERIAS, 1, 1, $this->_mes_competencia, $this->_mes_competencia
        )[0];
        $itemCalcFerias = new FpaitecalcfolhaEntity($this->entityManager, $this->hcmParameters, $calc_Ferias->getNrcalculofolha());
        $itemCalcFerias->retornaItensPorVinculo($vinculo->getNrorg(), $vinculo->getNrvinculom(), $calc_Ferias->getNrcalculofolha());
        $items = $itemCalcFerias->getItems();
        
        foreach($items as $item){
            if($item->getNreventom() == FpatipoassoceveEntity::ASSOC_LIQUIDO){
                $eventofecha = $this->_eventom->retornaEvento(FpatipoassoceveEntity::ASSOC_FECHADO);
                $itemCalcFerias->geraEvento($eventofecha, null, 0, 0, 1);
                $itemCalcFerias->persist();
            }
        }
        
        //Adiantamento
        $calc_Adiantamento = $this->entityManager->getRepository(Repositories::FPA_CALCULOFOLHA)->retornaCalculoFolha(
            $this->_nrorg, FpatipomovimentEntity::TP_MOV_ADIANTAMENTO, 1, 1, $this->_mes_competencia, $this->_mes_competencia
        )[0];
        $itemCalcAdiantamento = new FpaitecalcfolhaEntity($this->entityManager, $this->hcmParameters, $calc_Adiantamento->getNrcalculofolha());
        $itemCalcAdiantamento->retornaItensPorVinculo($vinculo->getNrorg(), $vinculo->getNrvinculom(), $calc_Adiantamento->getNrcalculofolha());
        
        foreach($itemCalcAdiantamento->getItems() as $item){
            if($item->getNreventom() == FpatipoassoceveEntity::ASSOC_LIQUIDO){
                $eventofecha = $this->_eventom->retornaEvento(FpatipoassoceveEntity::ASSOC_FECHADO);
                $itemCalcAdiantamento->geraEvento($eventofecha, null, 0, 0, 1);
                $itemCalcAdiantamento->persist();
            }
        }
        
        //13
        $calc_13 = $this->entityManager->getRepository(Repositories::FPA_CALCULOFOLHA)->retornaCalculoFolha(
            $this->_nrorg, FpatipomovimentEntity::TP_MOV_13SAL, 1, 1, $this->_mes_competencia, $this->_mes_competencia
        )[0];
        $itemCalc13 = new FpaitecalcfolhaEntity($this->entityManager, $this->hcmParameters, $calc_13->getNrcalculofolha());
        $itemCalc13->retornaItensPorVinculo($vinculo->getNrorg(), $vinculo->getNrvinculom(), $calc_13->getNrcalculofolha());
        
        foreach($itemCalc13->getItems() as $item){
            if($item->getNreventom() == FpatipoassoceveEntity::ASSOC_LIQUIDO){
                $eventofecha = $this->_eventom->retornaEvento(FpatipoassoceveEntity::ASSOC_FECHADO);
                $itemCalc13->geraEvento($eventofecha, null, 0, 0, 1);
                $itemCalc13->persist();
            }
        }
    }
}