<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\Repositories;
use HCM\Util\HCM;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;

class VinculoRepository {

    const ORDEM_ALFABETICA = 'ALFABETICA';
    const ORDEM_MATRICULA = 'MATRICULA';
    const ORDEM_DATA_ADMISSAO = 'DATA_ADMISSAO';
    const ORDEM_ESTRUTURA = 'ESTRUTURA';
    const ORDEM_LISTA_VINCULOS = 'LISTA_VINCULOS';

    protected  $connection;
    public function __construct(Connection $connection, EntityManager $entityManager, HCM $hcm, HCMParameters $hcmParameters) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->hcm = $hcm;
        $this->hcmParameters = $hcmParameters;
    }

    /**
     * @return array
     */
    public function getNrVinculoM($nrorg) {
        $maxIdQuery = "SELECT MAX(NRVINCULOM) AS MAX_ID FROM GPE_VINCULOM WHERE NRORG = {$nrorg}";
        return $this->connection->fetchAll($maxIdQuery);
    }

    public function getNrVinculoH($nrorg) {
        $maxIdQuery = "SELECT MAX(NRVINCULOH) AS MAX_ID FROM GPE_VINCULOH WHERE NRORG = {$nrorg}";
        return $this->connection->fetchAll($maxIdQuery);
        }

    public function retornaUltimoHistoricoCompetencia($nrorg, $nrvinculom, $dtmescompetenc) {
        $gpevinculoh = Repositories::GPE_VINCULOH;
        $qb = $this->entityManager->createQueryBuilder();
        $query = $qb->select("h")
            ->from($gpevinculoh, "h")
            ->where("h.nrorg = :nrorg")
            ->andWhere("h.nrvinculom = :nrvinculom")
            ->andWhere("h.dtmescompetenc = (select max(h1.dtmescompetenc) from $gpevinculoh h1 where h1.nrorg = h.nrorg and h1.nrvinculom = h.nrvinculom and h1.dtmescompetenc <= :dtmescompetenc)")
            ->setParameters(array('nrorg'=>$nrorg, 'nrvinculom'=>$nrvinculom, 'dtmescompetenc'=>$dtmescompetenc))
            ->getQuery();
        $historico = $query->getSingleResult();

        return $historico;
    }
    
    public function retornaHistoricoAnteriorUltimoHistorico($nrorg, $nrvinculom, $nrvinculoh, $dtmescompetenc) {
        $query = 'SELECT * 
                    FROM GPE_VINCULOH H
                   WHERE H.NRORG = :P_NRORG
                     AND H.NRVINCULOM = :P_NRVINCULOM
                     AND H.NRVINCULOH <> :P_NRVINCULOH
                     AND H.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC)
                                               FROM GPE_VINCULOH H1
                                              WHERE H1.NRORG = H.NRORG
                                                AND H1.NRVINCULOM = H.NRVINCULOM
                                                AND H1.NRVINCULOH <> :P_NRVINCULOH
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)';
        $params = array('P_NRORG'          => $nrorg, 
                        'P_NRVINCULOM'     => $nrvinculom,
                        'P_NRVINCULOH'     => $nrvinculoh, 
                        'P_DTMESCOMPETENC' => $dtmescompetenc);
                        
        $historico = $this->connection->fetchAssoc($query, $params);
        return $historico;
    }

    public function retornaVinculosAtivosCompetencia($nrorg, $dtmescompetenc, $nrestrutlegal, $nrestrutgeren, $nrtipovinculom) { 
        $filter = '';
        if($nrestrutlegal){
            $filter .= 'AND GPE_VINCULOH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL';
        }
        if($nrestrutgeren){
            $filter .= ' AND GPE_VINCULOH.NRESTRUTGEREN = :P_NRESTRUTGEREN';
        }
        if($nrtipovinculom){
            $filter .= ' AND GPE_VINCULOM.NRTIPOVINCULOM = :P_NRTIPOVINCULOM';
        }
        $query = "
            SELECT * FROM (
                  SELECT 
                       GPE_VINCULOM.NMVINCULOM,
                       GPE_VINCULOM.CDMATRICULA,
                       GPE_PESSOAH.NRCPFPESSOA,
                       GPE_PESSOAH.NRPESSOA,
                       GPE_VINCULOM.DTRESCISAOVINC,
                       GPE_VINCULOM.DTADMISSAOVINC,
                       GPE_VINCULOM.NRTIPOVINCULOM,
                       GPE_VINCULOH.*,
                       ESTRUTLEGAL.NMESTRUTURAM AS NMESTRUTLEGAL,
                       ESTRUTGEREN.NMESTRUTURAM AS NMESTRUTGEREN
                  FROM GPE_VINCULOM
                 INNER JOIN GPE_VINCULOH
                    ON GPE_VINCULOH.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                   AND GPE_VINCULOH.NRORG      = GPE_VINCULOM.NRORG
                   AND GPE_VINCULOH.DTMESCOMPETENC = (SELECT MAX(VH.DTMESCOMPETENC)
                                                        FROM GPE_VINCULOH VH
                                                       WHERE VH.NRORG          = GPE_VINCULOH.NRORG
                                                         AND VH.NRVINCULOM     = GPE_VINCULOH.NRVINCULOM
                                                         AND VH.DTMESCOMPETENC <= :P_DTMESCOMPETENCIA)
                 INNER JOIN GPE_PESSOAH
                    ON GPE_PESSOAH.NRPESSOA = GPE_VINCULOM.NRPESSOA
                   AND GPE_PESSOAH.NRORG    = GPE_VINCULOM.NRORG
                   AND GPE_PESSOAH.DTMESCOMPETENC = (SELECT MAX(PH.DTMESCOMPETENC)
                                                        FROM GPE_PESSOAH PH
                                                       WHERE PH.NRORG = GPE_PESSOAH.NRORG
                                                         AND PH.NRPESSOA = GPE_PESSOAH.NRPESSOA)
                  LEFT JOIN ESTRUTURAM ESTRUTLEGAL
                    ON ESTRUTLEGAL.NRESTRUTURAM = GPE_VINCULOH.NRESTRUTLEGAL
                   AND ESTRUTLEGAL.NRORG        = GPE_VINCULOH.NRORG
                  LEFT JOIN ESTRUTURAM ESTRUTGEREN
                    ON ESTRUTGEREN.NRESTRUTURAM = GPE_VINCULOH.NRESTRUTGEREN
                   AND ESTRUTGEREN.NRORG        = GPE_VINCULOH.NRORG
                 WHERE (GPE_VINCULOM.DTRESCISAOVINC IS NULL OR GPE_VINCULOM.DTRESCISAOVINC >= :P_DTMESCOMPETENCIA)
                   AND GPE_VINCULOM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENCIA)
                   AND GPE_VINCULOM.NRORG = :P_NRORG $filter) GPE_VINCULOM
             ORDER BY GPE_VINCULOM.NMVINCULOM";

        return $this->connection->fetchAll($query, array("P_DTMESCOMPETENCIA" => $dtmescompetenc,
                                                         "P_NRORG"            => $nrorg,
                                                         "P_NRESTRUTLEGAL"    => $nrestrutlegal,
                                                         "P_NRESTRUTGEREN"    => $nrestrutgeren,
                                                         "P_NRTIPOVINCULOM"   => $nrtipovinculom));
    }

    public function retornaVinculosCompetencia($nrOrg, $mesCompetencia, $rescindidos, $primeiroDiaAno, $dtUltDiaMes, $ds_inicio, $ds_fim, $dsOrdem, $carregaHistorico, $nrEstrutura,
                                               $verificaConfidencial, $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind, $paramCaged, $idapenasdesemp) {
          
          
      if ($paramCaged) {
            $condProcesso = "EXISTS (SELECT 1
                                      FROM GPE_MOVIMENTACAO MO
                                     WHERE MO.NRVINCULOM        = GPE_VINCULOM.NRVINCULOM
                                       AND MO.NRORG             = GPE_VINCULOM.NRORG
                                       AND TRUNC(MO.DTINIMOVIMENT) BETWEEN '".substr($mesCompetencia, 0, 10)."' AND '".substr($dtUltDiaMes, 0, 10)."') AND GPE_VINCULOM.NRVINCULOEMPREG <> 8";
            if($idapenasdesemp === 'S'){
                $condProcesso .= " AND (GPE_VINCULOM.DTRESCISAOVINC > '".substr($dtUltDiaMes, 0, 10)."' OR GPE_VINCULOM.DTRESCISAOVINC IS NULL) ";
            }    
        }else{       
           // define filtro de vínculos rescindidos na competência
           if ($rescindidos === true) {
              $condProcesso = "(GPE_VINCULOM.DTRESCISAOVINC IS NULL OR GPE_VINCULOM.DTRESCISAOVINC >= '".$mesCompetencia."')
                                AND GPE_VINCULOM.DTADMISSAOVINC <= '".$dtUltDiaMes."'";
           } else {
              $condProcesso = "(GPE_VINCULOM.DTRESCISAOVINC IS NULL OR GPE_VINCULOM.DTRESCISAOVINC > '".$dtUltDiaMes."')
                                AND GPE_VINCULOM.DTADMISSAOVINC <= '".$dtUltDiaMes."'";
           }
       }
      // define filtro por estrutura
      $condEstrutura = null;
      if (!empty($nrEstrutura)) {
          $condEstrutura = 'GPE_VINCULOH.NRESTRUTLEGAL = '.$nrEstrutura;
      }

      // define tipo de intervalo
      $condIntervalo = $this->buildOrdem($dsOrdem, $ds_inicio, $ds_fim, false, $paramCaged);
      // define orderby
      $ordenacao = self::_ordenaQuery($dsOrdem);      
      // constroi clasula where 
      $whereClause = $this->buildWhereClauseVinculosCompetencia($condProcesso, $condIntervalo, $condEstrutura, $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind, $ordenacao);

      $query = "
         SELECT MAXVINCH.DTMESCOMPETENC, GPE_VINCULOM.*
           FROM GPE_VINCULOM
          INNER JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NRVINCULOM, NRORG
                        FROM GPE_VINCULOH
                       WHERE DTMESCOMPETENC >= '".$primeiroDiaAno."'
                         AND DTMESCOMPETENC <= '".$dtUltDiaMes."'
                         AND NRORG =  ".$nrOrg."
                       GROUP BY NRVINCULOM, NRORG
                    ) MAXVINCH
                  ON MAXVINCH.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                 AND MAXVINCH.NRORG = GPE_VINCULOM.NRORG
          INNER JOIN GPE_VINCULOH
             ON GPE_VINCULOH.NRVINCULOM = MAXVINCH.NRVINCULOM
            AND GPE_VINCULOH.DTMESCOMPETENC = MAXVINCH.DTMESCOMPETENC
            AND GPE_VINCULOH.NRORG = MAXVINCH.NRORG
          ". $whereClause;
      $vinculos = $this->connection->fetchAll($query);
      if (!$carregaHistorico) {
          return $vinculos; 
      } else {

          $vinculosObj = array();
          foreach ($vinculos as $vinculo) {
              $vinculo = (object)$vinculo;

              /** @var $vinculoh \Folha\Entities\GpeVinculoh */
              $historico = $this->entityManager->getRepository('\Folha\Entities\GpeVinculoh')
                          ->retornaUltimoHistoricoCompetencia($nrOrg, $vinculo->NRVINCULOM, $mesCompetencia);

              $vinculo->historico = $historico;
              $vinculosObj[$vinculo->NRVINCULOM] = $vinculo;
          }          
          return $vinculosObj;
      }

    }

    public function retornaRescinditosCompetencia($nrOrg, $nrOrgPadrao, $mesCompetencia, $dtUltDiaMes, $primeiroDiaAno, $carregaHistorico, $nrEstrutura, $nrTipoVinculom, $nrVinculoEmpreg, $filters, $ds_inicio, $ds_fim, $dsOrdem, $nrEstrutSind, $todosRescindidos, $conditions, $movTransfSaida) {
        //$filterPlaceHolder = $this->hcm->getFilterPlaceHolder($filters);
        
        // define filtro de vínculos rescindidos na competência
        $condProcesso = "GPE_VINCULOM.DTRESCISAOVINC >= '".$mesCompetencia."'
                         AND GPE_VINCULOM.DTRESCISAOVINC <= '".$dtUltDiaMes."'";
        
        
        // define filtro por estrutura
        $condEstrutura = null;
        if (!empty($nrEstrutura)) {
            $condEstrutura = 'GPE_VINCULOH.NRESTRUTLEGAL = '.$nrEstrutura;
        }      
        // define tipo de intervalo
        $condIntervalo = $this->buildOrdem($dsOrdem, $ds_inicio, $ds_fim);
        // define orderby
        $ordenacao = self::_ordenaQuery($dsOrdem);
        
        // constroi clasula where 
        $whereClause = $this->buildWhereClauseVinculosCompetencia($condProcesso, $condIntervalo, $condEstrutura, $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind, $ordenacao);
        
        if(!$todosRescindidos){
            $whereClause = '';
        }
        
        $queryTransf = "";
        if ($movTransfSaida) {
            // constroi clasula where 
            $whereClauseTransf = $this->buildWhereClauseVinculosCompetencia('', $condIntervalo, '', $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind, $ordenacao);
        
            $queryTransf .= "
            UNION ALL
            SELECT MAXVINCH.DTMESCOMPETENC, GPE_VINCULOM.*, '' AS NMMOTIVORESC, 'Transferência de Saída' AS NMABREV
              FROM GPE_VINCULOM
             INNER JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NRVINCULOM, NRORG
                           FROM GPE_VINCULOH
                          WHERE DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE('".$mesCompetencia."'),'YEAR'),-12) 
                            AND DTMESCOMPETENC <= '".$mesCompetencia."'
                            AND NRORG =  ".$nrOrg."
                          GROUP BY NRVINCULOM, NRORG
                       ) MAXVINCH
                     ON MAXVINCH.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                    AND MAXVINCH.NRORG = GPE_VINCULOM.NRORG
             INNER JOIN GPE_VINCULOH
                ON GPE_VINCULOH.NRVINCULOM = MAXVINCH.NRVINCULOM
               AND GPE_VINCULOH.DTMESCOMPETENC = MAXVINCH.DTMESCOMPETENC
               AND GPE_VINCULOH.NRORG = MAXVINCH.NRORG
             INNER JOIN GPE_MOVIMENTACAO
               ON GPE_MOVIMENTACAO.NRORG = GPE_VINCULOM.NRORG
              AND GPE_MOVIMENTACAO.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
              AND GPE_MOVIMENTACAO.NRESTRUTURAM = $nrEstrutura
              AND GPE_MOVIMENTACAO.NRTPMOVTRANSFM = 9
              AND GPE_MOVIMENTACAO.DTFIMMOVIMENT BETWEEN '".$mesCompetencia."' AND '".$dtUltDiaMes."'
             INNER JOIN ESTRUTURAH
               ON ESTRUTURAH.NRORG = GPE_MOVIMENTACAO.NRORG
              AND ESTRUTURAH.NRESTRUTURAM = GPE_MOVIMENTACAO.NRESTRUTURAM
              AND ESTRUTURAH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                WHERE H1.NRORG = ESTRUTURAH.NRORG
                                                  AND H1.NRESTRUTURAM = ESTRUTURAH.NRESTRUTURAM
                                                  AND H1.DTMESCOMPETENC <= '".$mesCompetencia."')
             INNER JOIN GPE_MOVIMENTACAO MOVENTRADA
               ON MOVENTRADA.NRORG = GPE_VINCULOM.NRORG
              AND MOVENTRADA.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
              AND MOVENTRADA.NRTIPOESTRUTURA = GPE_MOVIMENTACAO.NRTIPOESTRUTURA
              AND MOVENTRADA.NRTIPOTRANSFER = GPE_MOVIMENTACAO.NRTIPOTRANSFER
              AND MOVENTRADA.NRTPMOVTRANSFM = 8
              AND MOVENTRADA.DTINIMOVIMENT > GPE_MOVIMENTACAO.DTFIMMOVIMENT
             INNER JOIN ESTRUTURAH ESTRUTENTRADA
               ON ESTRUTENTRADA.NRORG = MOVENTRADA.NRORG
              AND ESTRUTENTRADA.NRESTRUTURAM = MOVENTRADA.NRESTRUTURAM
              AND ESTRUTENTRADA.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                   WHERE H1.NRORG = ESTRUTENTRADA.NRORG
                                                     AND H1.NRESTRUTURAM = ESTRUTENTRADA.NRESTRUTURAM
                                                     AND H1.DTMESCOMPETENC <= '".$mesCompetencia."')
              AND SUBSTR(REPLACE(REPLACE(REPLACE(ESTRUTENTRADA.CDCNPJESTRUT,'.'),'/'),'-'),1,8) <> SUBSTR(REPLACE(REPLACE(REPLACE(ESTRUTURAH.CDCNPJESTRUT,'.'),'/'),'-'),1,8)
             ".$whereClauseTransf;
        }
        
        $query = "
            SELECT * FROM (SELECT MAXVINCH.DTMESCOMPETENC, GPE_VINCULOM.*, NMMOTIVORESC, NMABREV
                   FROM GPE_VINCULOM
                  INNER JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NRVINCULOM, NRORG
                                FROM GPE_VINCULOH
                               WHERE DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE('".$mesCompetencia."'),'YEAR'),-12) 
                                 AND DTMESCOMPETENC <= '".$mesCompetencia."'
                                 AND NRORG =  ".$nrOrg."
                               GROUP BY NRVINCULOM, NRORG
                            ) MAXVINCH
                          ON MAXVINCH.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                         AND MAXVINCH.NRORG = GPE_VINCULOM.NRORG
                  INNER JOIN GPE_VINCULOH
                     ON GPE_VINCULOH.NRVINCULOM = MAXVINCH.NRVINCULOM
                    AND GPE_VINCULOH.DTMESCOMPETENC = MAXVINCH.DTMESCOMPETENC
                    AND GPE_VINCULOH.NRORG = MAXVINCH.NRORG
                  LEFT JOIN FPA_TPDEMISSAO
                    ON GPE_VINCULOM.NRTPDEMISSAO = FPA_TPDEMISSAO.NRTPDEMISSAO
                   AND (GPE_VINCULOM.NRORG = FPA_TPDEMISSAO.NRORG OR FPA_TPDEMISSAO.NRORG = '".$nrOrgPadrao."')
                  LEFT JOIN GPE_MOTIVORESC
                    ON GPE_VINCULOM.NRMOTIVORESC = GPE_MOTIVORESC.NRMOTIVORESC
                   AND (GPE_VINCULOM.NRORG = GPE_MOTIVORESC.NRORG OR GPE_MOTIVORESC.NRORG = '".$nrOrgPadrao."')
                  ".$whereClause."
                  ".$queryTransf.") 
            WHERE 1 = 1 
            $conditions
            ORDER BY NMVINCULOM ASC"
        ;
        
        $vinculos = $this->connection->fetchAll($query);
        
        if (!$carregaHistorico) {
            return $vinculos;          
        
        } else {
        
            $vinculosObj = array();
            foreach ($vinculos as $vinculo) {
                $vinculo = (object)$vinculo;
        
                /** @var $vinculoh \Folha\Entities\GpeVinculoh */
                $historico = $this->entityManager->getRepository('\Folha\Entities\GpeVinculoh')
                            ->retornaUltimoHistoricoCompetencia($nrOrg, $vinculo->NRVINCULOM, $mesCompetencia);
                $vinculo->historico = $historico;
                $vinculosObj[$vinculo->NRVINCULOM] = $vinculo;
            }
            
            return $vinculosObj;
        }
    }
    
    public function retornaRescindidosGeral($mesCompetencia, $ds_inicio, $ds_fim, $dtini = null, $dtfim = null, $dsOrdem = null, $nrEstrutura = null, $carregaHistorico = null, $nrTipoVinculom = null,$nrVinculoEmpreg = null, $nrEstrutSind = null, $conditions = "") {
        $nrOrg = $this->hcmParameters->getNrorgTrabalho();
        $nrOrgPadrao = $this->hcmParameters->getNrorgPadrao();
        $ultimoDiaMesCompetencia = substr(DateUtil::getUltimoDiaDoMes($mesCompetencia), 0, 10);
        $mesCompetencia = substr($mesCompetencia, 0, 10);
        
        if (($dtini === null) || ($dtfim === null)) {
            $condProcesso = '(GPE_VINCULOM.DTRESCISAOVINC IS NOT NULL
                          AND GPE_VINCULOM.DTADMISSAOVINC <=  \''.$ultimoDiaMesCompetencia.'\')';
        }else{
            $condProcesso = '(GPE_VINCULOM.DTRESCISAOVINC IS NOT NULL AND GPE_VINCULOM.DTRESCISAOVINC BETWEEN \''.$dtini.'\' AND \''.$dtfim.'\'
                          AND GPE_VINCULOM.DTADMISSAOVINC <=  \''.$ultimoDiaMesCompetencia.'\')';
        }
        
        // define filtro por estrutura
        $condEstrutura = null;
        if ($nrEstrutura) {
          $condEstrutura = 'GPE_VINCULOH.NRESTRUTLEGAL = '.$nrEstrutura;
        }      

        // define tipo de intervalo
        $condIntervalo = $this->buildOrdem($dsOrdem, $ds_inicio, $ds_fim);
        
        // define orderby
        $ordenacao = self::_ordenaQuery($dsOrdem);
        
        // constroi clasula where 
        $whereClause = $this->buildWhereClauseVinculosCompetencia($condProcesso, $condIntervalo, $condEstrutura, $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind, $ordenacao);
        $whereSemOrderBy = explode("ORDER", $whereClause); // Na primeira posição do array, está a clausura where, e na segunda, a order by
        $whereComOrderBy = isset($whereSemOrderBy) ? $whereSemOrderBy[0] : null; 
        
        $query = "
        SELECT * 
          FROM (SELECT MAXVINCH.DTMESCOMPETENC, GPE_VINCULOM.*, NMMOTIVORESC, NMABREV
                  FROM GPE_VINCULOM
                 INNER JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NRVINCULOM, NRORG
                               FROM GPE_VINCULOH
                              WHERE DTMESCOMPETENC <= '".$mesCompetencia."'
                                AND NRORG =  ".$nrOrg."
                              GROUP BY NRVINCULOM, NRORG) MAXVINCH
                         ON MAXVINCH.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                        AND MAXVINCH.NRORG = GPE_VINCULOM.NRORG
                 INNER JOIN GPE_VINCULOH
                         ON GPE_VINCULOH.NRVINCULOM = MAXVINCH.NRVINCULOM
                        AND GPE_VINCULOH.DTMESCOMPETENC = MAXVINCH.DTMESCOMPETENC
                        AND GPE_VINCULOH.NRORG = MAXVINCH.NRORG
                  LEFT JOIN FPA_TPDEMISSAO
                         ON GPE_VINCULOM.NRTPDEMISSAO = FPA_TPDEMISSAO.NRTPDEMISSAO
                        AND (GPE_VINCULOM.NRORG = FPA_TPDEMISSAO.NRORG OR FPA_TPDEMISSAO.NRORG = '".$nrOrgPadrao."')
                  LEFT JOIN GPE_MOTIVORESC
                         ON GPE_VINCULOM.NRMOTIVORESC = GPE_MOTIVORESC.NRMOTIVORESC
                        AND (GPE_VINCULOM.NRORG = GPE_MOTIVORESC.NRORG OR GPE_MOTIVORESC.NRORG = '".$nrOrgPadrao."')
               ".$whereComOrderBy.")
        WHERE 1 = 1
        ".$conditions."
        ORDER BY NMVINCULOM";
        
        $vinculos = $this->connection->fetchAll($query);
        
        if (!$carregaHistorico) {
           return $vinculos;          
        
        } else {
        
          $vinculosObj = array();
          foreach ($vinculos as $vinculo) {
              $vinculo = (object)$vinculo;
        
              /** @var $vinculoh \Folha\Entities\GpeVinculoh */
              $historico = $this->entityManager->getRepository('\Folha\Entities\GpeVinculoh')
                          ->retornaUltimoHistoricoCompetencia($nrOrg, $vinculo->NRVINCULOM, $mesCompetencia);
              $vinculo->historico = $historico;
              $vinculosObj[$vinculo->NRVINCULOM] = $vinculo;
          }          
          
          return $vinculosObj;
        }

    }

    private function buildOrdem($dsOrdem, $ds_inicio, $ds_fim, $validaQuery = false, $paramCaged = false) {      
        $condIntervalo = null;
        if($validaQuery){
            if ( ( !empty($dsOrdem) && !empty($ds_inicio) ) || ( $dsOrdem === 'ESTRUTURA' ) ) {
                switch ($dsOrdem) {
                    case 'ALFABETICA':
                        $condIntervalo = "VM.NMVINCULOM_M BETWEEN '$ds_inicio' AND '$ds_fim'";
                        break;
                    case 'ESTRUTURA':
                        if($ds_inicio)
                            $condIntervalo  = "VH.NRESTRUTLEGAL_H = '$ds_inicio' ";
                        if($ds_inicio && $ds_fim)
                            $condIntervalo .= "AND VH.NRESTRUTGEREN_H = '$ds_fim' ";
                        else if(!$ds_inicio && $ds_fim)
                            $condIntervalo .= "VH.NRESTRUTGEREN_H = '$ds_fim' ";
                        break;
                        
                    case 'MATRICULA':
                        $condIntervalo = "VM.CDMATRICULA_M BETWEEN '$ds_inicio' AND '$ds_fim'";
                        break;
                        
                    case 'DATA_ADMISSAO':
                        $condIntervalo = "VM.DTADMISSAOVINC_M BETWEEN '$ds_inicio' AND '$ds_fim'";
                        break;
                        
                    case 'LISTA_VINCULO':
                        $ds_inicio = is_array($ds_inicio) ? implode(',',$ds_inicio) : $ds_inicio;
                        $condIntervalo = "VM.NRVINCULOM IN ($ds_inicio)";
                        break;
                    case 'LISTA_ESTRUTURA':
                        $ds_inicio = is_array($ds_inicio) ? implode(',',$ds_inicio) : $ds_inicio;
                        $condIntervalo = "VH.NRESTRUTLEGAL IN ($ds_inicio)";
                        if($ds_fim){
                            $ds_fim = is_array($ds_fim) ? implode(',',$ds_fim) : $ds_fim;
                            $condIntervalo .= "AND VH.NRESTRUTGEREN IN ($ds_fim)";
                        }
                        break;  
                    case 'LISTA_BANCOS':
                        $ds_inicio = is_array($ds_inicio) ? implode(',',$ds_inicio) : $ds_inicio;
                        $condIntervalo = "EXISTS (SELECT 1 
                                                    FROM CONTCORRPARC
                                                    JOIN GPE_PESSOA ON GPE_PESSOA.NRPARCNEGOCIO = CONTCORRPARC.NRPARCNEGOCIO
                                                                   AND GPE_PESSOA.NRORG = CONTCORRPARC.NRORG
                                                   WHERE CONTCORRPARC.CDBANCO IN ($ds_inicio)
                                                     AND CONTCORRPARC.NRORG = GPE_VINCULOM.NRORG
                                                     AND GPE_PESSOA.NRPESSOA = GPE_VINCULOM.NRPESSOA)";
                        break;
                }
            }
            
        }else{
            if ( ( !empty($dsOrdem) && !empty($ds_inicio) ) || ( $dsOrdem === 'ESTRUTURA' && $ds_fim ) ) {
                switch ($dsOrdem) {
                    case 'ALFABETICA':
                        $condIntervalo = "GPE_VINCULOM.NMVINCULOM BETWEEN '$ds_inicio' AND '$ds_fim'";
                        break;
                        
                    case 'ESTRUTURA':
                        if($paramCaged === false){
                            if($ds_inicio)
                                $condIntervalo  = "GPE_VINCULOH.NRESTRUTLEGAL = '$ds_inicio' ";
                            if($ds_inicio && $ds_fim)
                                $condIntervalo .= "AND GPE_VINCULOH.NRESTRUTGEREN = '$ds_fim' ";
                            else if(!$ds_inicio && $ds_fim)
                                $condIntervalo .= "GPE_VINCULOH.NRESTRUTGEREN = '$ds_fim' ";
                        } else {
                            if($ds_fim){
                                $condIntervalo =
                                    "(
                                        (GPE_VINCULOH.NRESTRUTLEGAL = '$ds_inicio' AND GPE_VINCULOH.NRESTRUTGEREN = '$ds_fim')
                                        OR
                                        (EXISTS (SELECT *
                                                   FROM GPE_MOVIMENTACAO
                                                  WHERE NRORG = GPE_VINCULOM.NRORG
                                                    AND NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                                                    AND NRESTRUTURAM = '$ds_inicio'
                                                    AND NRTPMOVTRANSFM = 9))
                                     )";
                            }else{
                                $condIntervalo =
                                    "(
                                        GPE_VINCULOH.NRESTRUTLEGAL = '$ds_inicio'
                                        OR
                                        (EXISTS (SELECT *
                                                   FROM GPE_MOVIMENTACAO
                                                  WHERE NRORG = GPE_VINCULOM.NRORG
                                                    AND NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                                                    AND NRESTRUTURAM = '$ds_inicio'
                                                    AND NRTPMOVTRANSFM = 9))
                                     )";
                            }
                        }
                        break;
                        
                    case 'MATRICULA':
                        $condIntervalo = "GPE_VINCULOM.CDMATRICULA BETWEEN '$ds_inicio' AND '$ds_fim'";
                        break;
                        
                    case 'DATA_ADMISSAO':
                        $condIntervalo = "GPE_VINCULOM.DTADMISSAOVINC BETWEEN '$ds_inicio' AND '$ds_fim'";
                        break;
                    case 'LISTA_VINCULO':
                        $ds_inicio = is_array($ds_inicio) ? implode(',',$ds_inicio) : $ds_inicio;
                        $condIntervalo = "GPE_VINCULOM.NRVINCULOM IN ($ds_inicio)";
                        break;
                    case 'LISTA_ESTRUTURA':
                        $ds_inicio = is_array($ds_inicio) ? implode(',',$ds_inicio) : $ds_inicio;
                        $condIntervalo = "GPE_VINCULOH.NRESTRUTLEGAL IN ($ds_inicio)";
                        if($ds_fim){
                            $ds_fim = is_array($ds_fim) ? implode(',',$ds_fim) : $ds_fim;
                            $condIntervalo .= "AND GPE_VINCULOH.NRESTRUTGEREN IN ($ds_fim)";
                        }
                        break;
                    case 'LISTA_BANCOS':
                        $ds_inicio = is_array($ds_inicio) ? implode(',',$ds_inicio) : $ds_inicio;
                        $condIntervalo = "EXISTS (SELECT 1 
                                                    FROM CONTCORRPARC
                                                    JOIN GPE_PESSOA ON GPE_PESSOA.NRPARCNEGOCIO = CONTCORRPARC.NRPARCNEGOCIO
                                                                   AND GPE_PESSOA.NRORG = CONTCORRPARC.NRORG
                                                   WHERE CONTCORRPARC.CDBANCO IN ($ds_inicio)
                                                     AND CONTCORRPARC.NRORG = GPE_VINCULOM.NRORG
                                                     AND GPE_PESSOA.NRPESSOA = GPE_VINCULOM.NRPESSOA)";
                        break;
                }
            }
        }
        return $condIntervalo;
    }

    private static function _ordenaQuery($ordem, $validaQuery = false) {
        if($validaQuery){
            switch ($ordem) {
                case self::ORDEM_ALFABETICA:
                    $nomeColuna = 'VM.NMVINCULOM_M';
                    break;
                case self::ORDEM_DATA_ADMISSAO:
                    $nomeColuna = 'VM.DTADMISSAOVINC_M';
                    break;
                case self::ORDEM_ESTRUTURA:
                    $nomeColuna = 'VH.NRESTRUTLEGAL_H';
                    break;
                case self::ORDEM_MATRICULA:
                    $nomeColuna = 'VM.CDMATRICULA_M';
                    break;
                case self::ORDEM_LISTA_VINCULOS:
                    $nomeColuna = 'VM.NRVINCULOM_M';
                    break;
                default:
                    $nomeColuna = null;
            }
            
        }else{
            switch ($ordem) {
                case self::ORDEM_ALFABETICA:
                    $nomeColuna = 'GPE_VINCULOM.NMVINCULOM';
                    break;
                case self::ORDEM_DATA_ADMISSAO:
                    $nomeColuna = 'GPE_VINCULOM.DTADMISSAOVINC';
                    break;
                case self::ORDEM_ESTRUTURA:
                    $nomeColuna = 'GPE_VINCULOH.NRESTRUTLEGAL';
                    break;
                case self::ORDEM_MATRICULA:
                    $nomeColuna = 'GPE_VINCULOM.CDMATRICULA';
                    break;
                case self::ORDEM_LISTA_VINCULOS:
                    $nomeColuna = 'GPE_VINCULOM.NRVINCULOM';
                    break;
                default:
                    $nomeColuna = null;
            }
        }    

        if (!empty($nomeColuna)) {
          return 'ORDER BY '.$nomeColuna;
        }

        return $nomeColuna;
    }

    private function buildWhereClauseVinculosCompetencia($condProcesso, $condIntervalo, $condEstrutura, $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind, $ordenacao) {

        $processo = false;
        $intervalo = false;
        $estrutura = false;

        $where = ' WHERE ';

        if (!empty($condProcesso)) {
            $where .= $condProcesso;
            $processo = true;
        }

        if (!empty($condIntervalo)) {
            if ($processo === true) {
                $where .= ' AND ';
            }

            $where .= $condIntervalo;
            $intervalo = true;
        }

        if (!empty($condEstrutura)) {
            if (($processo === true) || ($intervalo === true)) {
                $where .= ' AND ';
            }

            $where .= $condEstrutura;
            $estrutura = true;
        }

        if ($processo === false
            && $intervalo === false
            && $estrutura === false
        ) {
            $where .= ' (1=1) ';
        }

        if($nrTipoVinculom != null) {
            if ($where != ' WHERE ')
                $where .= ' AND ';

            $where .= 'GPE_VINCULOM.NRTIPOVINCULOM = '.$nrTipoVinculom;
        }

        if($nrVinculoEmpreg != null) {
            if ($where != ' WHERE ')
                $where .= ' AND ';

              $where .= 'GPE_VINCULOM.NRVINCULOEMPREG = '.$nrVinculoEmpreg;
        }

        if($nrEstrutSind != null) {
            if ($where != ' WHERE ')
                $where .= ' AND ';

            $where .= 'GPE_VINCULOH.NRESTRUTSIND = '.$nrEstrutSind;
        }

        if (empty($ordenacao) === false) {
            $where .= ' '.$ordenacao;
        }

        return $where;
    }

    public function verificaCalculoMovimentoVinculo($nrvinculom, $nrOrg, $mesCompetencia, $nrtpmodalidcal, $ocorrecal, $nrtipomoviment) {
      /* verifica se o vínculo possui calculo gravado para o movimento na competência, que o líquido seja maior que zero ou
         que exista evento '760 - Complemento de Líquido Negativo' */
      $sql = "
        SELECT 'true' AS VERIFICA_CALCULO
          FROM FPA_ITECALCFOLHA ICF
          JOIN FPA_CALCULOFOLHA CF ON CF.NRORG          = ICF.NRORG
                                  AND CF.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                  AND CF.NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT
                                  AND CF.NRTPMODALIDCAL = :P_NRTPMODALIDCAL
                                  AND CF.DTOCORRENCIA   = :P_COMPETENCIA
                                  AND CF.NROCORRECAL    = :P_OCORRECAL
         WHERE ICF.NRORG       = :P_NRORG
           AND ICF.NRVINCULOM  = :P_NRVINCULOM
           AND ICF.NREVENTOM  IN (3030, 760)
           AND ROUND(ICF.VREVENTOFOLHA, 2) > 0
      ";

      $return = $this->connection->fetchAll($sql, array(
          "P_NRTIPOMOVIMENT" => $nrtipomoviment,
          "P_NRTPMODALIDCAL" => $nrtpmodalidcal,
          "P_COMPETENCIA"    => $mesCompetencia,
          "P_OCORRECAL"      => $ocorrecal,
          "P_NRORG"          => $nrOrg,
          "P_NRVINCULOM"     => $nrvinculom
      ));
      
      if (count($return) > 0)
        return true;
      else 
        return false;

    }
    
    public function getFichaFinanceira($parameters, $conditions){	 
        $query = "SELECT * 	 
                    FROM (SELECT FPA_ITECALCFOLHA.*,	 
                                 FPA_CALCULOFOLHA.NRTIPOMOVIMENT,	 
                                 FPA_CALCULOFOLHA.NRTPMODALIDCAL,	 
                                 FPA_CALCULOFOLHA.NROCORRECAL,	 
                                 FPA_CALCULOFOLHA.DTOCORRENCIA DTMESCOMPETENC,   	 
                                 FPA_TPMODALIDCAL.NMTPMODALIDCAL,	 
                                 FPA_TIPOMOVIMENT.NMTIPOMOVIMENT,	 
                                 FPA_EVENTOH.NMEVENTOH,	 
                                 FPA_EVENTOM.IDTIPOEVENTO,	 
                                 FPA_EVENTOH.IDUNIDREFEREVEN,	 
                                 FPA_EVENTOH.NRNATURUBR,	 
                                 NATUREZARUBRICA.NMNATURUBR,	 
                                 NATUREZARUBRICA.CDESOCIAL	 
                            FROM GPE_VINCULOM 	 
                            JOIN FPA_CALCULOFOLHA ON FPA_CALCULOFOLHA.NRORG = GPE_VINCULOM.NRORG	 
                                                AND FPA_CALCULOFOLHA.NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT	 
                                                AND FPA_CALCULOFOLHA.NRTPMODALIDCAL = :P_NRTPMODALIDCAL	 
                                                AND FPA_CALCULOFOLHA.NROCORRECAL = :P_NROCORRECAL	 
                                                AND FPA_CALCULOFOLHA.DTOCORRENCIA = :P_DTMESCOMPETENC	 
                            JOIN FPA_ITECALCFOLHA ON FPA_ITECALCFOLHA.NRVINCULOM = GPE_VINCULOM.NRVINCULOM	 
                                                AND FPA_ITECALCFOLHA.NRORG = GPE_VINCULOM.NRORG   	 
                                                AND FPA_ITECALCFOLHA.NRCALCULOFOLHA = FPA_CALCULOFOLHA.NRCALCULOFOLHA	 
                            JOIN FPA_TPMODALIDCAL ON FPA_TPMODALIDCAL.NRTPMODALIDCAL = FPA_CALCULOFOLHA.NRTPMODALIDCAL 	 
                                                 AND (FPA_TPMODALIDCAL.NRORG = FPA_CALCULOFOLHA.NRORG OR FPA_TPMODALIDCAL.NRORG = :P_NRORG_PADRAO)	 
                            JOIN FPA_TIPOMOVIMENT ON FPA_TIPOMOVIMENT.NRTIPOMOVIMENT = FPA_CALCULOFOLHA.NRTIPOMOVIMENT 	 
                                                 AND (FPA_TIPOMOVIMENT.NRORG = FPA_CALCULOFOLHA.NRORG OR FPA_TIPOMOVIMENT.NRORG = :P_NRORG_PADRAO) 	 
                            JOIN FPA_EVENTOM ON FPA_EVENTOM.NREVENTOM = FPA_ITECALCFOLHA.NREVENTOM	 
                                            AND (FPA_EVENTOM.NRORG = FPA_ITECALCFOLHA.NRORG OR FPA_EVENTOM.NRORG = :P_NRORG_PADRAO)	 
                            JOIN FPA_EVENTOH ON FPA_EVENTOH.NREVENTOM = FPA_EVENTOM.NREVENTOM	 
                                            AND FPA_EVENTOH.NRORG = FPA_EVENTOM.NRORG	 
                                            AND FPA_EVENTOH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC) 	 
                                                                                FROM FPA_EVENTOH EHH	 
                                                                               WHERE EHH.NRORG = FPA_EVENTOH.NRORG	 
                                                                                 AND EHH.NREVENTOM = FPA_EVENTOH.NREVENTOM	 
                                                                                 AND EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)	 
                       LEFT JOIN NATUREZARUBRICA ON NATUREZARUBRICA.NRNATURUBR = FPA_EVENTOH.NRNATURUBR	 
                                                AND (NATUREZARUBRICA.NRORG = FPA_ITECALCFOLHA.NRORG OR NATUREZARUBRICA.NRORG = :P_NRORG_PADRAO) 	 
                           WHERE GPE_VINCULOM.NRORG = :P_NRORG	 
                             AND GPE_VINCULOM.NRVINCULOM = :P_NRVINCULOM)	 
                   WHERE 1 = 1	 
                   ".$conditions;	 
                   	 
        return $this->connection->fetchAll($query, $parameters);	 
    	 
    }
    
    /**
     * Retorna array de vínculos com  historico agregado.
     */
    public function retornaOnlyObjectVinculosCompetencia($nrOrg, $mesCompetencia, $rescindidos, $primeiroDiaAno, $dtUltDiaMes, $ds_inicio, $ds_fim, $dsOrdem, $carregaHistorico, $nrEstrutura,
                                               $verificaConfidencial, $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind) {
    // define filtro de vínculos rescindidos na competência
    if ($rescindidos === true) {
      $condProcesso = "(GPE_VINCULOM.DTRESCISAOVINC IS NULL OR GPE_VINCULOM.DTRESCISAOVINC >= '".$mesCompetencia."')
                        AND GPE_VINCULOM.DTADMISSAOVINC <= '".$dtUltDiaMes."'";
    } else {
      $condProcesso = "(GPE_VINCULOM.DTRESCISAOVINC IS NULL OR GPE_VINCULOM.DTRESCISAOVINC > '".$dtUltDiaMes."')
                        AND GPE_VINCULOM.DTADMISSAOVINC <= '".$dtUltDiaMes."'";
    }
    
    // define filtro por estrutura
    $condEstrutura = null;
    if ($nrEstrutura) {
      $condEstrutura = 'GPE_VINCULOH.NRESTRUTLEGAL = '.$nrEstrutura;
    }
    
    // define tipo de intervalo
    $condIntervalo = $this->buildOrdem($dsOrdem, $ds_inicio, $ds_fim);
    // define orderby
    $ordenacao = self::_ordenaQuery($dsOrdem);      
    // constroi clasula where 
    $whereClause = $this->buildWhereClauseVinculosCompetencia($condProcesso, $condIntervalo, $condEstrutura, $nrTipoVinculom, $nrVinculoEmpreg, $nrEstrutSind, $ordenacao);
        $query = 
            "SELECT        
                GPE_VINCULOM.NRVINCULOM  AS NRVINCULOM_M,
                GPE_VINCULOM.NRPESSOA AS NRPESSOA_M,
                GPE_VINCULOM.NRORG AS NRORG_M,
                GPE_VINCULOM.DTADMISSAOVINC AS DTADMISSAOVINC_M,
                GPE_VINCULOM.DTRESCISAOVINC AS DTRESCISAOVINC_M,
                GPE_VINCULOM.CDMATRICULA AS CDMATRICULA_M,
                GPE_VINCULOM.DTINCLUSAO AS DTINCLUSAO_M,
                GPE_VINCULOM.DTULTATU AS DTULTATU_M,
                GPE_VINCULOM.NRORGINCLUSAO AS NRORGINCLUSAO_M,
                GPE_VINCULOM.CDOPERINCLUSAO AS CDOPERINCLUSAO_M,
                GPE_VINCULOM.NRORGULTATU AS NRORGULTATU_M,
                GPE_VINCULOM.CDOPERULTATU AS CDOPERULTATU_M,
                GPE_VINCULOM.NRTIPOVINCULOM AS NRTIPOVINCULOM_M,
                GPE_VINCULOM.NRVINCULOEMPREG AS NRVINCULOEMPREG_M,
                GPE_VINCULOM.NRTPADMISSAO AS NRTPADMISSAO_M,
                GPE_VINCULOM.NRTPDEMISSAO AS NRTPDEMISSAO_M,
                GPE_VINCULOM.DTOPCAOFGTS AS DTOPCAOFGTS_M,
                GPE_VINCULOM.DTAPOSENTAFGTS AS DTAPOSENTAFGTS_M,
                GPE_VINCULOM.DTPRIMADMISSAO AS DTPRIMADMISSAO_M,
                GPE_VINCULOM.NMVINCULOM AS NMVINCULOM_M,
                GPE_VINCULOM.NRMOTIVORESC AS NRMOTIVORESC_M,
                GPE_VINCULOM.DSOBSRESCISAO AS DSOBSRESCISAO_M,
                GPE_VINCULOM.DTAVISOPREVIO AS DTAVISOPREVIO_M,
                GPE_VINCULOM.NRDIASCONTRATOEXP AS NRDIASCONTRATOEXP_M,
                GPE_VINCULOM.NRDIASCONTRATOEXPPRO AS NRDIASCONTRATOEXPPRO_M,
                GPE_VINCULOM.DTEXAMEMEDICO AS DTEXAMEMEDICO_M,
                GPE_VINCULOM.DTAVISOTRCT AS DTAVISOTRCT_M,
                GPE_VINCULOM.DSLIVROADMISSAO AS DSLIVROADMISSAO_M,
                GPE_VINCULOM.IDSEGDESEMPVINC AS IDSEGDESEMPVINC_M,
                GPE_VINCULOM.NRDIASAPURVALES AS NRDIASAPURVALES_M,
                GPE_VINCULOM.NRTPAVIPRE AS NRTPAVIPRE_M,
                GPE_VINCULOM.DTENTREGAEPI AS DTENTREGAEPI_M,
                GPE_VINCULOM.DSOBSERVACAORESCISAO AS DSOBSERVACAORESCISAO_M,
                GPE_VINCULOM.IDVERIFICARESCISAO AS IDVERIFICARESCISAO_M,
                GPE_VINCULOH.NRVINCULOH AS NRVINCULOH_H, 
                GPE_VINCULOH.NRVINCULOM AS NRVINCULOM_H,
                GPE_VINCULOH.NRSITUFUNCM AS NRSITUFUNCM_H,
                GPE_VINCULOH.NRCARGO AS NRCARGO_H,
                GPE_VINCULOH.NRESCALATRABM AS NRESCALATRABM_H,
                GPE_VINCULOH.NRORG AS NRORG_H,
                GPE_VINCULOH.DTMESCOMPETENC AS DTMESCOMPETENC_H,
                GPE_VINCULOH.IDCONTRIBUISIND AS IDCONTRIBUISIND_H,
                GPE_VINCULOH.DTINCLUSAO AS DTINCLUSAO_H,
                GPE_VINCULOH.DTULTATU AS DTULTATU_H,
                GPE_VINCULOH.NRORGINCLUSAO AS NRORGINCLUSAO_H,
                GPE_VINCULOH.CDOPERINCLUSAO AS CDOPERINCLUSAO_H,
                GPE_VINCULOH.NRORGULTATU AS NRORGULTATU_H,
                GPE_VINCULOH.CDOPERULTATU AS CDOPERULTATU_H,
                GPE_VINCULOH.NRDEPENDIR AS NRDEPENDIR_H,
                GPE_VINCULOH.NRDEPENDSFAM AS NRDEPENDSFAM_H,
                GPE_VINCULOH.DTBASEFERIAS AS DTBASEFERIAS_H,
                GPE_VINCULOH.IDREMUNERACAO AS IDREMUNERACAO_H,
                GPE_VINCULOH.IDTPPAGAMENTO AS IDTPPAGAMENTO_H,
                GPE_VINCULOH.NRESTRUTLEGAL AS NRESTRUTLEGAL_H,
                GPE_VINCULOH.NRESTRUTGEREN AS NRESTRUTGEREN_H,
                GPE_VINCULOH.NRTPMODALIDSAL AS NRTPMODALIDSAL_H,
                GPE_VINCULOH.IDMULTVINC AS IDMULTVINC_H,
                GPE_VINCULOH.NRFUNCAO AS NRFUNCAO_H,
                GPE_VINCULOH.CDCONTRIBINDIVIDUAL AS CDCONTRIBINDIVIDUAL_H,
                GPE_VINCULOH.NRTPMOVTRANSFM AS NRTPMOVTRANSFM_H,
                GPE_VINCULOH.DTFIMCONTRDETERMIN AS DTFIMCONTRDETERMIN_H,
                GPE_VINCULOH.NRESTRUTSIND AS NRESTRUTSIND_H,
                GPE_VINCULOH.CONFIDENCIAL AS CONFIDENCIAL_H,
                GPE_VINCULOH.NRDIASAPURVALES AS NRDIASAPURVALES_H,
                GPE_VINCULOH.NRTURNO AS NRTURNO_H,
                GPE_VINCULOH.NRTPREGIMEPREV AS NRTPREGIMEPREV_H
            FROM 
                GPE_VINCULOH GPE_VINCULOH
                INNER JOIN GPE_VINCULOM GPE_VINCULOM ON GPE_VINCULOM.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
            AND GPE_VINCULOH.NRORG = GPE_VINCULOM.NRORG
              AND 
                GPE_VINCULOH.DTMESCOMPETENC = ( SELECT MAX(GPE_VINCULOHH.DTMESCOMPETENC) FROM GPE_VINCULOH GPE_VINCULOHH
                                         WHERE GPE_VINCULOHH.DTMESCOMPETENC >= '".$primeiroDiaAno."'
                         			       AND GPE_VINCULOHH.DTMESCOMPETENC <= '".$dtUltDiaMes."'
                         			       AND GPE_VINCULOHH.NRORG = '".$nrOrg."'
                                           AND GPE_VINCULOHH.NRVINCULOM = GPE_VINCULOH.NRVINCULOM 
                                           AND GPE_VINCULOHH.NRORG = GPE_VINCULOH.NRORG)
            ".$whereClause;
        try{
            $vinculosSQL = $this->connection->fetchAll($query);
            $vinculosArray = [];
            $vinculom = Repositories::GPE_VINCULOM;
            $vinculoh = Repositories::GPE_VINCULOH;
            foreach ($vinculosSQL as $vincData) {
                $mestre = new $vinculom();
                $mestre->setNrvinculom($vincData['NRVINCULOM_M']);
                $mestre->setNrpessoa($vincData['NRPESSOA_M']);
                $mestre->setNrorg($vincData['NRORG_M']);
                $mestre->setDtadmissaovinc(DateUtil::getDataDeString($vincData['DTADMISSAOVINC_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setDtrescisaovinc(DateUtil::getDataDeString($vincData['DTRESCISAOVINC_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setCdmatricula($vincData['CDMATRICULA_M']);
                $mestre->setDtinclusao(DateUtil::getDataDeString($vincData['DTINCLUSAO_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setDtultatu(DateUtil::getDataDeString($vincData['DTULTATU_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setNrorginclusao($vincData['NRORGINCLUSAO_M']);
                $mestre->setCdoperinclusao($vincData['CDOPERINCLUSAO_M']);
                $mestre->setNrorgultatu($vincData['NRORGULTATU_M']);
                $mestre->setCdoperultatu($vincData['CDOPERULTATU_M']);
                $mestre->setNrtipovinculom($vincData['NRTIPOVINCULOM_M']);
                $mestre->setNrvinculoempreg($vincData['NRVINCULOEMPREG_M']);
                $mestre->setNrtpadmissao($vincData['NRTPADMISSAO_M']);
                $mestre->setNrtpdemissao($vincData['NRTPDEMISSAO_M']);
                $mestre->setDtopcaofgts(DateUtil::getDataDeString($vincData['DTOPCAOFGTS_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setDtaposentafgts(DateUtil::getDataDeString($vincData['DTAPOSENTAFGTS_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setDtprimadmissao(DateUtil::getDataDeString($vincData['DTPRIMADMISSAO_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setNmvinculom($vincData['NMVINCULOM_M']);
                $mestre->setNrmotivoresc($vincData['NRMOTIVORESC_M']);
                $mestre->setDsobsrescisao($vincData['DSOBSRESCISAO_M']);
                $mestre->setDtavisoprevio(DateUtil::getDataDeString($vincData['DTAVISOPREVIO_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setNrdiascontratoexp($vincData['NRDIASCONTRATOEXP_M']);
                $mestre->setNrdiascontratoexppro($vincData['NRDIASCONTRATOEXPPRO_M']);
                $mestre->setDtexamemedico(DateUtil::getDataDeString($vincData['DTEXAMEMEDICO_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $mestre->setDtavisotrct($vincData['DTAVISOTRCT_M']);
                $mestre->setDslivroadmissao($vincData['DSLIVROADMISSAO_M']);
                $mestre->setIdsegdesempvinc($vincData['IDSEGDESEMPVINC_M']);
                $mestre->setNrdiasapurvales($vincData['NRDIASAPURVALES_M']);
                $mestre->setNrtpavipre($vincData['NRTPAVIPRE_M']);
                $mestre->setDtentregaepi(DateUtil::getDataDeString($vincData['DTENTREGAEPI_M'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));

                $historico = new $vinculoh();
                $historico->setNrvinculoh($vincData['NRVINCULOH_H']);
                $historico->setNrvinculom($vincData['NRVINCULOM_H']);
                $historico->setNrsitufuncm($vincData['NRSITUFUNCM_H']);
                $historico->setNrcargo($vincData['NRCARGO_H']);
                $historico->setNrescalatrabm($vincData['NRESCALATRABM_H']);
                $historico->setNrorg($vincData['NRORG_H']);
                $historico->setDtmescompetenc(DateUtil::getDataDeString($vincData['DTMESCOMPETENC_H'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $historico->setIdcontribuisind($vincData['IDCONTRIBUISIND_H']);
                $historico->setDtinclusao(DateUtil::getDataDeString($vincData['DTINCLUSAO_H'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $historico->setDtultatu(DateUtil::getDataDeString($vincData['DTULTATU_H'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $historico->setNrorginclusao($vincData['NRORGINCLUSAO_H']);
                $historico->setCdoperinclusao($vincData['CDOPERINCLUSAO_H']);
                $historico->setNrorgultatu($vincData['NRORGULTATU_H']);
                $historico->setCdoperultatu($vincData['CDOPERULTATU_H']);
                $historico->setNrdependir($vincData['NRDEPENDIR_H']);
                $historico->setNrdependsfam($vincData['NRDEPENDSFAM_H']);
                $historico->setDtbaseferias(DateUtil::getDataDeString($vincData['DTBASEFERIAS_H'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $historico->setIdremuneracao($vincData['IDREMUNERACAO_H']);
                $historico->setIdtppagamento($vincData['IDTPPAGAMENTO_H']);
                $historico->setNrestrutlegal($vincData['NRESTRUTLEGAL_H']);
                $historico->setNrestrutgeren($vincData['NRESTRUTGEREN_H']);
                $historico->setNrtpmodalidsal($vincData['NRTPMODALIDSAL_H']);
                $historico->setIdmultvinc($vincData['IDMULTVINC_H']);
                $historico->setNrfuncao($vincData['NRFUNCAO_H']);
                $historico->setCdcontribindividual($vincData['CDCONTRIBINDIVIDUAL_H']);
                $historico->setNrtpmovtransfm($vincData['NRTPMOVTRANSFM_H']);
                $historico->setDtfimcontrdetermin(DateUtil::getDataDeString($vincData['DTFIMCONTRDETERMIN_H'], DateUtil::FORMATO_BRASILEIRO_DATAHORA));
                $historico->setNrestrutsind($vincData['NRESTRUTSIND_H']);
                $historico->setConfidencial($vincData['CONFIDENCIAL_H']);
                $historico->setNrdiasapurvales($vincData['NRDIASAPURVALES_H']);
                $historico->setNrturno($vincData['NRTURNO_H']);
                $historico->setNrtpregimeprev($vincData['NRTPREGIMEPREV_H']);
                
                $mestre->historico = $historico;
                $vinculosArray[] = $mestre;
            }
        } catch (Exception $e){
            echo $e->getMessage().'<br/>';
        }
        
        return $vinculosArray;
    }
    
    public function getVinculosMatriculaEsocial($parameters, $conditions){
        $query = "SELECT * 
                    FROM (SELECT VM.NRVINCULOM, 
                                 VM.NRPESSOA, 
                                 VM.NRORG, 
                                 VM.DTADMISSAOVINC, 
                                 VM.DTRESCISAOVINC, 
                                 VM.CDMATRICULA, 
                                 VM.NRTIPOVINCULOM, 
                                 VM.NRVINCULOEMPREG, 
                                 VM.NRTPADMISSAO, 
                                 VM.NRTPDEMISSAO, 
                                 VM.NMVINCULOM, 
                                 VM.NRMOTIVORESC, 
                                 VM.DSOBSRESCISAO, 
                                 VM.DTAVISOPREVIO, 
                                 VM.NRDIASCONTRATOEXP,
                                 VM.NRDIASCONTRATOEXPPRO,
                                 VM.DTRETORNO, 
                                 VM.DTEFEITOFINANCEIRO, 
                                 VM.OBSREINTEGRACAO, 
                                 VM.DTCANCAVIPRE, 
                                 VM.NRMOTIVOCANCAP, 
                                 VM.DSOBSCANCAVIPRE, 
                                 VM.DTESOCIAL, 
                                 VM.DTVENCCONTREXPER, 
                                 VM.NRCLAUSASSECURAT, 
                                 VH.NRVINCULOH,
                                 VH.NRSITUFUNCM, 
                                 VH.NRCARGO, 
                                 VH.NRESCALATRABM,
                                 VH.IDCONTRIBUISIND,
                                 VH.NRDEPENDIR, 
                                 VH.NRDEPENDSFAM,
                                 VH.DTBASEFERIAS, 
                                 VH.IDREMUNERACAO, 
                                 VH.IDTPPAGAMENTO, 
                                 VH.NRESTRUTLEGAL, 
                                 VH.NRESTRUTGEREN, 
                                 VH.NRTPMODALIDSAL, 
                                 VH.IDMULTVINC, 
                                 VH.NRFUNCAO, 
                                 VH.CDCONTRIBINDIVIDUAL, 
                                 VH.NRTPMOVTRANSFM, 
                                 VH.DTFIMCONTRDETERMIN,
                                 VH.NRESTRUTSIND, 
                                 VH.CONFIDENCIAL,
                                 VH.NRTURNO, 
                                 VH.NRTPREGIMEPREV, 
                                 VH.IDASSOCSINDICATO, 
                                 VH.CDMATRICULAESOCIAL, 
                                 VH.NRFAIXA, 
                                 VH.IDPAGPROPFER13,
                                 TH.NMTIPOVINCULOH
                            FROM GPE_VINCULOM VM
                            JOIN GPE_VINCULOH VH ON VH.NRVINCULOM = VM.NRVINCULOM
                                                AND VH.NRORG = VM.NRORG
                                                AND VH.DTMESCOMPETENC = (SELECT MAX(VHH.DTMESCOMPETENC)
                                                                           FROM GPE_VINCULOH VHH
                                                                          WHERE VHH.NRVINCULOM = VH.NRVINCULOM
                                                                            AND VHH.NRORG = VH.NRORG
                                                                            AND VHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                            JOIN GPE_TIPOVINCULOH TH ON TH.NRTIPOVINCULOM = VM.NRTIPOVINCULOM
                                                    AND (TH.NRORG = 0 OR TH.NRORG = VM.NRORG)
                                                    AND TH.DTMESCOMPETENC = (SELECT MAX(THH.DTMESCOMPETENC)
                                                                               FROM GPE_TIPOVINCULOH THH
                                                                              WHERE THH.NRTIPOVINCULOM = TH.NRTIPOVINCULOM
                                                                                AND THH.NRORG = TH.NRORG
                                                                                AND THH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                           WHERE VM.NRORG = :P_NRORG
                             AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM 
                             AND (VH.CDMATRICULAESOCIAL IS NOT NULL 
                                    OR VM.NRTIPOVINCULOM IN (2, 3, 10)))
                    WHERE 1 = 1".$conditions;
        
        return $this->connection->fetchAll($query, $parameters);	 
    }
    
    public function alteraBeneficiários($nrvinculom, $dtRescisao, $nrorg) {
        $idativoAtualizado = empty($dtRescisao) ? 'S' : 'N';
        
        $sql = "UPDATE
                  VAB_BENEFICIARIO
                SET
                  DTCANCBENEFICIARIO = :P_DTCANCBENEFICIARIO,
                  CDOPERULTATU = :P_CDOPERADOR,
                  NRORGULTATU = :P_NRORG,
                  DTULTATU = SYSDATE,
                  IDATIVO = :P_IDATIVO
                WHERE
                  NRVINCULOM = :P_NRVINCULOM
                  AND NRORG = :P_NRORG";
                  
        $params = array(
            "P_DTCANCBENEFICIARIO"  => $dtRescisao,
            "P_NRVINCULOM"          => $nrvinculom,
            "P_NRORG"               => $nrorg,
            "P_CDOPERADOR"          => $this->hcmParameters->getCdoperador(),
            "P_IDATIVO"             => $idativoAtualizado
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}