CREATE OR REPLACE PROCEDURE PRE_VALIDACAO_DAPI_MG(
   P_CDIMPOSTO    IN IMPOSTO.CDIMPOSTO%TYPE,
   P_CDEMPRESA    IN EMPRESA.CDEMPRESA%TYPE,
   P_NRSEQUMAPAPU IN MAPAAPURAC.NRSEQUMAPAPU%TYPE,
   P_INSCRICAO    IN NOTAFISCAL.CDINSCESTA%TYPE,
   P_IDORGARRECAD IN IMPOSTO.IDORGARRECAD%TYPE,
   P_CDLIVROMAG   IN LIVROMAGNETICO.CDLIVROMAG%TYPE)
AS
   V_TOTALITIMP   NUMBER;
   V_TOTALIMPNF   NUMBER;
   V_VRCONTITIMP  NUMBER;
   V_SEQERRO      NUMBER;
   V_STSEQERRO    VARCHAR2(3);
   V_DTINIMAPA    DATE;
   V_DTFIMMAPA    DATE;
   V_SEQUENCIAL   NUMBER;
   V_DIFERENCA    FLOAT;   
   V_IDUTDESCICMS VARCHAR2(1);

BEGIN
   DELETE FROM ERRONFPREVALID
   WHERE (CDFILIAL, NRLANCTONF) IN (SELECT CDFILIAL, NRLANCTONF
                                      FROM IMPOSTONF
                                     WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
                                       AND DSTIPOVALIDA = 'DAPI');


   FOR C_NF IN (SELECT DISTINCT N.CDFILIAL, N.NRLANCTONF, N.CDMODDOCFISC, N.NRNOTAFISC, N.IDENTRSAIDOP, N.NRACESSONFE, N.VRNOTAFISC,
                       N.DTEMISSAO, N.DTENTRSAID, N.CDFORNECED, N.CDCLIENTE, N.CDFILIEMIT, N.CDFILIRECE, N.CDSERIEENTR, N.CDSERIE
                  FROM NOTAFISCAL N, IMPOSTONF I, IMPOSTO IM
                 WHERE N.CDFILIAL      = I.CDFILIAL
                   AND N.NRLANCTONF    = I.NRLANCTONF
                   AND ((N.IDSISTEMA   <> 'FIS') AND (N.IDSISTEMA   <> 'TMP'))
                   AND ((N.CDINSCESTA  = P_INSCRICAO AND P_IDORGARRECAD = 'E') OR
                        (N.CDINSCMUNI  = P_INSCRICAO AND P_IDORGARRECAD = 'M') OR
                        (P_INSCRICAO IS NULL        AND (P_IDORGARRECAD = 'F' OR P_IDORGARRECAD IS NULL)))
                   AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                   AND IM.CDIMPOSTO    = I.CDIMPOSTO
                   AND I.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                 ORDER BY N.CDFILIAL, N.NRLANCTONF) LOOP

      V_SEQERRO := 0;

      BEGIN
         SELECT NVL(MAX(IDUTDESCICMS), 'N')
           INTO V_IDUTDESCICMS
           FROM CLIENTE
          WHERE CDCLIENTE = C_NF.CDCLIENTE;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_IDUTDESCICMS := 'N';
      END;

      BEGIN
         SELECT DTINIPERIODO, DTFIMPERIODO
           INTO V_DTINIMAPA, V_DTFIMMAPA
           FROM MAPAAPURAC
          WHERE CDIMPOSTO = P_CDIMPOSTO
            AND CDEMPRESA = P_CDEMPRESA
            AND NRSEQUMAPAPU = P_NRSEQUMAPAPU
            AND ((CDINSCESTA = P_INSCRICAO) OR (CDINSCMUNI = P_INSCRICAO) OR (P_INSCRICAO IS NULL));
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_DTINIMAPA   := NULL;
            V_DTFIMMAPA   := NULL;            
      END;

      IF C_NF.DTEMISSAO > V_DTFIMMAPA THEN
         V_SEQERRO   := V_SEQERRO + 1;
         V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
         INSERT INTO ERRONFPREVALID
            (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
         VALUES
             (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
             'A data de emisso da nota deve ser menor ou igual  data final do mapa de apurao', 'MODELO', 'A');
      END IF;
      IF (C_NF.DTENTRSAID > V_DTFIMMAPA) AND (C_NF.CDMODDOCFISC NOT IN ('06','29','28')) THEN
          V_SEQERRO   := V_SEQERRO + 1;
          V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
          INSERT INTO ERRONFPREVALID
             (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
          VALUES
             (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
             'A data de entrada da nota deve ser menor ou igual  data final do mapa de apurao', 'MODELO', 'A');
      END IF;
      BEGIN
         IF TO_NUMBER(C_NF.NRNOTAFISC) = 0 THEN
            V_SEQERRO   := V_SEQERRO + 1;
            V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
            INSERT INTO ERRONFPREVALID
               (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
            VALUES
               (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
               'Nmero da nota fiscal deve ser maior que zero', 'NUMERO', 'E');
         END IF;
      EXCEPTION
        WHEN VALUE_ERROR THEN
           V_SEQERRO   := V_SEQERRO + 1;
           V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
           INSERT INTO ERRONFPREVALID
              (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
           VALUES
              (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
              'Nmero da nota fiscal possui caracteres invlidos', 'NUMERO', 'E');
      END;
      IF C_NF.IDENTRSAIDOP = 'S' AND C_NF.CDMODDOCFISC = '55' THEN
         IF C_NF.NRACESSONFE IS NULL THEN
            V_SEQERRO   := V_SEQERRO + 1;
            V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
            INSERT INTO ERRONFPREVALID
               (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
            VALUES
               (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
               'Nota Fiscal de modelo 55 sem chave de Nota Fiscal Eletrnica', 'CHAVE_NFE', 'E');
         END IF;
      END IF;

      FOR C_ITEMNF IN (SELECT CDSITUTRIBIT, CDFISCOPERIT, CDFISCALIT, VRBASECALCIT, VRALIQITEM, VRIMPOSTOIT,
                              I.NRSEQITPROD, NRITPROIMPOS, P.CDPRODUTO, I.VRCONTITIMP, I.VRPERREDBCIT,
                              PP.CDARVPROD, PP.NMPRODUTO
                         FROM ITEMPROIMPOS I, ITEMPRODUTO P, PRODUTO PP, IMPOSTO IM, NOTAFISCAL N
                        WHERE I.CDFILIAL   = C_NF.CDFILIAL
                          AND I.NRLANCTONF = C_NF.NRLANCTONF
                          AND I.NRLANCTONF = N.NRLANCTONF
                          AND I.CDFILIAL   = N.CDFILIAL
                          AND ((N.IDSISTEMA   <> 'FIS') AND (N.IDSISTEMA   <> 'TMP'))
                          AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                          AND IM.CDIMPOSTO = I.CDIMPOSTO
                          AND P.CDFILIAL = I.CDFILIAL
                          AND P.NRLANCTONF = I.NRLANCTONF
                          AND P.NRSEQITPROD = I.NRSEQITPROD
                          AND PP.CDPRODUTO = P.CDPRODUTO
                        ORDER BY I.CDIMPOSTO, I.NRSEQITPROD
                      ) LOOP
         V_SEQUENCIAL := NVL(V_SEQUENCIAL,0)+1;
         IF C_ITEMNF.CDSITUTRIBIT IS NULL THEN
            V_SEQERRO   := V_SEQERRO + 1;
            V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
            INSERT INTO ERRONFPREVALID
               (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
            VALUES
               (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
               'Item com CST vazio. (Item: '||V_SEQUENCIAL||')', 'CST', 'E');
         ELSIF LENGTH(C_ITEMNF.CDSITUTRIBIT) <> 3 THEN
            V_SEQERRO   := V_SEQERRO + 1;
            V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
            INSERT INTO ERRONFPREVALID
               (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
            VALUES
               (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
               'CST com tamanho invlido. O CST do item deve possuir 3 dgitos. (Item '||V_SEQUENCIAL||')', 'CST', 'E');
         END IF;
         IF C_ITEMNF.CDFISCOPERIT IS NULL THEN
            V_SEQERRO   := V_SEQERRO + 1;
            V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
            INSERT INTO ERRONFPREVALID
               (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
            VALUES
               (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
               'Item da nota fiscal lanado sem CFOP. (Item: '||V_SEQUENCIAL||')', 'CFOP', 'E');
         ELSIF LENGTH(C_ITEMNF.CDFISCOPERIT) <> 4 THEN
            V_SEQERRO   := V_SEQERRO + 1;
            V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
            INSERT INTO ERRONFPREVALID
               (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
            VALUES
               (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
               'CFOP com tamanho invlido. O CFOP do item deve ter 4 dgitos. (Item: '||V_SEQUENCIAL||')', 'CFOP', 'E');
         END IF;
         IF C_ITEMNF.CDSITUTRIBIT = '000' THEN
            IF C_ITEMNF.CDFISCALIT <> '1' THEN
               V_SEQERRO   := V_SEQERRO + 1;
               V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
               INSERT INTO ERRONFPREVALID
                  (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
               VALUES
                  (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
                  'CST 000 com cdigo fiscal '||C_ITEMNF.CDFISCALIT||'. O cdigo fiscal para itens de CST 000 deve ser 1. (Item: '||V_SEQUENCIAL||')', 'CF', 'E');
            END IF;
         END IF;
         IF C_ITEMNF.CDFISCALIT = '1' THEN
            IF C_ITEMNF.VRBASECALCIT = 0 THEN
               V_SEQERRO   := V_SEQERRO + 1;
               V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
               INSERT INTO ERRONFPREVALID
                  (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
               VALUES
                  (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
                  'O valor da base de clculo no pode ser zero para itens de cdigo fiscal 1. (Item: '||V_SEQUENCIAL||')', 'CF', 'E');
            END IF;
         END IF;

         IF C_ITEMNF.NRITPROIMPOS = 2 THEN
            IF (C_ITEMNF.VRBASECALCIT > 0) OR (C_ITEMNF.VRIMPOSTOIT > 0) THEN
               V_SEQERRO   := V_SEQERRO + 1;
               V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
               INSERT INTO ERRONFPREVALID
                  (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
               VALUES
                  (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
                  'Item de reduo de base de clculo com imposto ou base de clculo maiores do que zero. Em caso de reduo estes valores devem ser zero. (Item: '||V_SEQUENCIAL||')', 'REDU_BASE_CALC', 'E');
            END IF;
         END IF;
         IF C_ITEMNF.VRCONTITIMP < 0 THEN
            V_SEQERRO   := V_SEQERRO + 1;
            V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
            INSERT INTO ERRONFPREVALID
               (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
            VALUES
               (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
                'Item com valor contbil negativo. (Item: '||V_SEQUENCIAL||')', 'VR_CONTABIL', 'E');
         END IF;
      END LOOP;
      
      FOR C_NFCFOP IN (SELECT DISTINCT LINHA, NRLANCTONF, CDFILIAL, CDFISCOPERNF
                      FROM (SELECT CDOPERDAPI AS LINHA,
                                   '01' AS COLUNA,
                                   I.NRLANCTONF,
                                   I.CDFILIAL,
                                   I.CDFISCOPERNF
                              FROM IMPOSTONF I, OPERDAPISEF OP, IMPOSTO IM,
                                   (SELECT DISTINCT N.IDENTRSAIDOP,I.CDFILIAL,
                                           I.NRLANCTONF,
                                           I.CDFISCOPERNF
                                      FROM MAPAAPURAC M,IMPOSTONF I,NOTAFISCAL N,IMPOSTO IM
                                     WHERE M.CDIMPOSTO     = P_CDIMPOSTO
                                       AND M.CDEMPRESA     = P_CDEMPRESA
                                       AND M.CDINSCESTA    = P_INSCRICAO
                                       AND M.NRSEQUMAPAPU  = I.NRSEQUMAPAPU
                                       AND M.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                                       AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                                       AND IM.CDIMPOSTO    = I.CDIMPOSTO
                                       AND I.NRLANCTONF    = N.NRLANCTONF
                                       AND N.NRLANCTONF    = C_NF.NRLANCTONF                                       
                                       AND I.CDFILIAL      = N.CDFILIAL
                                       AND N.CDFILIAL      = C_NF.CDFILIAL
                                       AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL)))N
                             WHERE IM.CDIMPOSTONFE = P_CDIMPOSTO
                               AND IM.CDIMPOSTO    = I.CDIMPOSTO
                               AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL))
                               AND N.NRLANCTONF    = I.NRLANCTONF
                               AND N.CDFILIAL      = I.CDFILIAL
                               AND OP.CDCFOPRELAC(+)  = I.CDFISCOPERNF
                         UNION ALL
                            SELECT CDOPERDAPI AS LINHA,
                                   '02' AS COLUNA,
                                   I.NRLANCTONF, 
                                   I.CDFILIAL,
                                   I.CDFISCOPERNF
                              FROM IMPOSTONF I, OPERDAPISEF OP, IMPOSTO IM,
                                   (SELECT DISTINCT N.IDENTRSAIDOP,I.CDFILIAL, I.NRLANCTONF, I.CDFISCOPERNF
                                      FROM MAPAAPURAC M,IMPOSTONF I,NOTAFISCAL N,IMPOSTO IM
                                     WHERE M.CDIMPOSTO     = P_CDIMPOSTO
                                       AND M.CDEMPRESA     = P_CDEMPRESA
                                       AND M.CDINSCESTA    = P_INSCRICAO
                                       AND M.NRSEQUMAPAPU  = I.NRSEQUMAPAPU
                                       AND M.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                                       AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                                       AND IM.CDIMPOSTO    = I.CDIMPOSTO
                                       AND I.NRLANCTONF    = N.NRLANCTONF
                                       AND N.NRLANCTONF    = C_NF.NRLANCTONF                                       
                                       AND I.CDFILIAL      = N.CDFILIAL
                                       AND N.CDFILIAL      = C_NF.CDFILIAL
                                       AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL)))N
                             WHERE IM.CDIMPOSTONFE = P_CDIMPOSTO
                               AND IM.CDIMPOSTO    = I.CDIMPOSTO
                               AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL))
                               AND N.NRLANCTONF    = I.NRLANCTONF
                               AND N.CDFILIAL      = I.CDFILIAL
                               AND OP.CDCFOPRELAC(+)  = I.CDFISCOPERNF
                         UNION ALL
                            SELECT CDOPERDAPI AS LINHA,
                                   '03' AS COLUNA,
                                   I.NRLANCTONF,
                                   I.CDFILIAL,
                                   I.CDFISCOPERNF
                              FROM IMPOSTONF I, OPERDAPISEF OP, IMPOSTO IM,
                                   (SELECT DISTINCT N.IDENTRSAIDOP,I.CDFILIAL, I.NRLANCTONF, I.CDFISCOPERNF
                                      FROM MAPAAPURAC M,IMPOSTONF I,NOTAFISCAL N,IMPOSTO IM
                                     WHERE M.CDIMPOSTO     = P_CDIMPOSTO
                                       AND M.CDEMPRESA     = P_CDEMPRESA
                                       AND M.CDINSCESTA    = P_INSCRICAO
                                       AND M.NRSEQUMAPAPU  = I.NRSEQUMAPAPU
                                       AND M.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                                       AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                                       AND IM.CDIMPOSTO    = I.CDIMPOSTO
                                       AND I.NRLANCTONF    = N.NRLANCTONF
                                       AND N.NRLANCTONF    = C_NF.NRLANCTONF                                       
                                       AND I.CDFILIAL      = N.CDFILIAL
                                       AND N.CDFILIAL      = C_NF.CDFILIAL
                                       AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL)))N
                             WHERE IM.CDIMPOSTONFE = P_CDIMPOSTO
                               AND IM.CDIMPOSTO    = I.CDIMPOSTO
                               AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL))
                               AND N.NRLANCTONF    = I.NRLANCTONF
                               AND N.CDFILIAL      = I.CDFILIAL
                               AND OP.CDCFOPRELAC(+)  = I.CDFISCOPERNF
                         UNION ALL
                            SELECT CDOPERDAPI AS LINHA,
                                   DECODE(N.IDENTRSAIDOP,'E','05','04')  AS COLUNA,
                                   I.NRLANCTONF,
                                   I.CDFILIAL,
                                   I.CDFISCOPERNF
                              FROM IMPOSTONF I, OPERDAPISEF OP, IMPOSTO IM,
                                   (SELECT DISTINCT N.IDENTRSAIDOP,I.CDFILIAL, I.NRLANCTONF, I.CDFISCOPERNF
                                      FROM MAPAAPURAC M,IMPOSTONF I,NOTAFISCAL N,IMPOSTO IM
                                     WHERE M.CDIMPOSTO     = P_CDIMPOSTO
                                       AND M.CDEMPRESA     = P_CDEMPRESA
                                       AND M.CDINSCESTA    = P_INSCRICAO
                                       AND M.NRSEQUMAPAPU  = I.NRSEQUMAPAPU
                                       AND M.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                                       AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                                       AND IM.CDIMPOSTO    = I.CDIMPOSTO
                                       AND I.NRLANCTONF    = N.NRLANCTONF
                                       AND N.NRLANCTONF    = C_NF.NRLANCTONF                                       
                                       AND I.CDFILIAL      = N.CDFILIAL
                                       AND N.CDFILIAL      = C_NF.CDFILIAL
                                       AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL)))N
                             WHERE IM.CDIMPOSTONFE = P_CDIMPOSTO
                               AND IM.CDIMPOSTO    = I.CDIMPOSTO
                               AND ((I.IDIMPOSTONF <> '3') AND (I.IDIMPOSTONF <> '2'))
                               AND N.NRLANCTONF    = I.NRLANCTONF
                               AND N.CDFILIAL      = I.CDFILIAL
                               AND OP.CDCFOPRELAC(+)  = I.CDFISCOPERNF
                         UNION ALL
                            SELECT CDOPERDAPI AS LINHA,
                                   DECODE(N.IDENTRSAIDOP,'E','07','06')  AS COLUNA,
                                   I.NRLANCTONF,
                                   I.CDFILIAL,
                                   I.CDFISCOPERNF
                              FROM IMPOSTONF I, OPERDAPISEF OP, IMPOSTO IM,
                                   (SELECT DISTINCT N.IDENTRSAIDOP,I.CDFILIAL, I.NRLANCTONF, I.CDFISCOPERNF
                                      FROM MAPAAPURAC M,IMPOSTONF I,NOTAFISCAL N,IMPOSTO IM
                                     WHERE M.CDIMPOSTO     = P_CDIMPOSTO
                                       AND M.CDEMPRESA     = P_CDEMPRESA
                                       AND M.CDINSCESTA    = P_INSCRICAO
                                       AND M.NRSEQUMAPAPU  = I.NRSEQUMAPAPU
                                       AND M.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                                       AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                                       AND IM.CDIMPOSTO    = I.CDIMPOSTO
                                       AND I.NRLANCTONF    = N.NRLANCTONF
                                       AND N.NRLANCTONF    = C_NF.NRLANCTONF                                       
                                       AND I.CDFILIAL      = N.CDFILIAL
                                       AND N.CDFILIAL      = C_NF.CDFILIAL
                                       AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL)))N
                             WHERE IM.CDIMPOSTONFE = P_CDIMPOSTO
                               AND IM.CDIMPOSTO    = I.CDIMPOSTO
                               AND I.IDIMPOSTONF   = '2'
                               AND N.NRLANCTONF    = I.NRLANCTONF
                               AND N.CDFILIAL      = I.CDFILIAL
                               AND OP.CDCFOPRELAC(+)  = I.CDFISCOPERNF
                         UNION ALL
                            SELECT CDOPERDAPI AS LINHA,
                                   DECODE(N.IDENTRSAIDOP,'E','10','09')  AS COLUNA,
                                   I.NRLANCTONF,
                                   I.CDFILIAL,
                                   I.CDFISCOPERNF
                              FROM IMPOSTONF I, OPERDAPISEF OP, IMPOSTO IM,
                                   (SELECT DISTINCT N.IDENTRSAIDOP,I.CDFILIAL, I.NRLANCTONF, I.CDFISCOPERNF
                                      FROM MAPAAPURAC M,IMPOSTONF I,NOTAFISCAL N,IMPOSTO IM
                                     WHERE M.CDIMPOSTO     = P_CDIMPOSTO
                                       AND M.CDEMPRESA     = P_CDEMPRESA
                                       AND M.CDINSCESTA    = P_INSCRICAO
                                       AND M.NRSEQUMAPAPU  = I.NRSEQUMAPAPU
                                       AND M.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                                       AND IM.CDIMPOSTONFE = '80'
                                       AND IM.CDIMPOSTO    = I.CDIMPOSTO
                                       AND I.NRLANCTONF    = N.NRLANCTONF
                                       AND N.NRLANCTONF    = C_NF.NRLANCTONF                                       
                                       AND I.CDFILIAL      = N.CDFILIAL
                                       AND N.CDFILIAL      = C_NF.CDFILIAL
                                       AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL)))N
                             WHERE IM.CDIMPOSTONFE = '80'
                               AND IM.CDIMPOSTO    = I.CDIMPOSTO
                               AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL))
                               AND N.NRLANCTONF    = I.NRLANCTONF
                               AND N.CDFILIAL      = I.CDFILIAL
                               AND (OP.CDCFOPRELAC(+) = I.CDFISCOPERNF)
                         UNION ALL
                            SELECT CDOPERDAPI AS LINHA,
                                   DECODE(N.IDENTRSAIDOP,'E','11','10') AS COLUNA,
                                   I.NRLANCTONF,
                                   I.CDFILIAL,
                                   I.CDFISCOPERNF
                              FROM IMPOSTONF I, OPERDAPISEF OP, IMPOSTO IM,
                                   (SELECT DISTINCT N.IDENTRSAIDOP,I.CDFILIAL, I.NRLANCTONF, I.CDFISCOPERNF
                                      FROM MAPAAPURAC M,IMPOSTONF I,NOTAFISCAL N,IMPOSTO IM
                                     WHERE M.CDIMPOSTO     = P_CDIMPOSTO
                                       AND M.CDEMPRESA     = P_CDEMPRESA
                                       AND M.CDINSCESTA    = P_INSCRICAO
                                       AND M.NRSEQUMAPAPU  = I.NRSEQUMAPAPU
                                       AND M.NRSEQUMAPAPU  = P_NRSEQUMAPAPU
                                       AND IM.CDIMPOSTONFE = P_CDIMPOSTO
                                       AND IM.CDIMPOSTO    = I.CDIMPOSTO
                                       AND I.NRLANCTONF    = N.NRLANCTONF
                                       AND N.NRLANCTONF    = C_NF.NRLANCTONF                                       
                                       AND I.CDFILIAL      = N.CDFILIAL
                                       AND N.CDFILIAL      = C_NF.CDFILIAL
                                       AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL)))N
                             WHERE IM.CDIMPOSTONFE = P_CDIMPOSTO
                               AND IM.CDIMPOSTO    = I.CDIMPOSTO
                               AND ((I.IDIMPOSTONF <> '3') OR (I.IDIMPOSTONF IS NULL))
                               AND N.NRLANCTONF    = I.NRLANCTONF
                               AND N.CDFILIAL      = I.CDFILIAL
                               AND (OP.CDCFOPRELAC(+) = I.CDFISCOPERNF))
                     WHERE LINHA IS NULL
                       AND CDFISCOPERNF IS NOT NULL
                     ORDER BY 1,2 ) LOOP
                     
      V_SEQERRO   := V_SEQERRO + 1;
      V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
      INSERT INTO ERRONFPREVALID
          (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
      VALUES
          (C_NFCFOP.CDFILIAL, C_NFCFOP.NRLANCTONF, V_STSEQERRO, 'DAPI',
          'O CFOP '||C_NFCFOP.CDFISCOPERNF||' no foi relacionado na tela "Cadastro de Operaes DAPISEF"', 'RELACCFOP', 'E');
   END LOOP;      
      
      V_SEQUENCIAL := 0;
      BEGIN
         SELECT ROUND(SUM(VRCONTITIMP),2)
           INTO V_TOTALITIMP
           FROM ITEMPROIMPOS I, IMPOSTO IM
          WHERE CDFILIAL   = C_NF.CDFILIAL
            AND NRLANCTONF = C_NF.NRLANCTONF
            AND IM.CDIMPOSTONFE = P_CDIMPOSTO
            AND NVL(I.NRITPROIMPOS,'3') <> '3'
            AND IM.CDIMPOSTO = I.CDIMPOSTO;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_TOTALITIMP := 0;
      END;
      BEGIN
         SELECT ROUND(SUM(VRCONTABILNF),2)
           INTO V_TOTALIMPNF
           FROM IMPOSTONF I, IMPOSTO IM
          WHERE CDFILIAL   = C_NF.CDFILIAL
            AND NRLANCTONF = C_NF.NRLANCTONF
            AND IM.CDIMPOSTONFE = P_CDIMPOSTO
            AND NVL(I.IDIMPOSTONF,'3') <> '3'
            AND IM.CDIMPOSTO = I.CDIMPOSTO;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_TOTALIMPNF := 0;
      END;
      IF V_TOTALITIMP <> V_TOTALIMPNF THEN
         V_SEQERRO   := V_SEQERRO + 1;
         V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
         INSERT INTO ERRONFPREVALID
            (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
         VALUES
            (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
            'Valor contbil dos itens da nota  diferente do valor contbil do analtico por imposto. (Valor do analtico R$'||V_TOTALITIMP||'. Valor dos itens da nota R$'||V_TOTALIMPNF||')', 'VR_CONTABIL', 'E');
      END IF;

      IF (V_IDUTDESCICMS = 'N') THEN
         IF V_TOTALITIMP <> ROUND(C_NF.VRNOTAFISC,2) THEN
            /* DIFERENCA DE VALORES */
            V_DIFERENCA := ROUND(C_NF.VRNOTAFISC,2) - V_TOTALITIMP;
            IF V_DIFERENCA > 0.10 THEN
               V_SEQERRO   := V_SEQERRO + 1;
               V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
               INSERT INTO ERRONFPREVALID
                  (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
               VALUES
                  (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
                  'A soma dos itens do analtico por imposto no  igual ao valor do documento. (Valor do documento R$'||C_NF.VRNOTAFISC||'. Soma dos analticos R$'||V_TOTALITIMP||')', 'VR_CONTABIL', 'E');
            END IF;
         END IF;
         V_DIFERENCA := 0;
      END IF;

      IF V_TOTALIMPNF < 0 THEN
         V_SEQERRO   := V_SEQERRO + 1;
         V_STSEQERRO := LPAD(TO_CHAR(V_SEQERRO), 3, '0');
         INSERT INTO ERRONFPREVALID
            (CDFILIAL, NRLANCTONF, NRSEQERRONFPRE, DSTIPOVALIDA, DSERRONFPRE, IDERRONFPRE, IDERROAVISNFPRE)
         VALUES
            (C_NF.CDFILIAL, C_NF.NRLANCTONF, V_STSEQERRO, 'DAPI',
            'Nota com valor contbil negativo', 'VR_CONTABIL', 'E');
      END IF;
   END LOOP;
END;
/
-- VERSAO --
BEGIN ATUVEROBJ('PRE_VALIDACAO_DAPI_MG','5.67.000'); END;
/
