<?php
//define('HCM_ERROR_REPORTING', (E_ALL | E_STRICT) ^ (E_WARNING | E_NOTICE));
require_once __DIR__ . '/../../backend/bootstrap.php';

/*
    README

    - O script pode ser utilizado para realizar uma validação de execução das queries dos eventos do eSocial
    afim de encontrar erros de sintaxe, nome de tabelas/campos ou incoerência de parâmetros utilizados.
    - NÃO FAZ VALIDAÇÃO DE DADOS RETORNADOS.
    - As queries são encontradas pelo texto "<<<SQL ... SQL;"
    - Os parâmetros são encontradas pelo texto "params = array(...);"
    - Os diretórios utlizados no script consideram que este arquivo php está localizado na pasta /hcm/scripts/esocial/
*/

function main() 
{
    echo "Script para validar as queries do eSocial\n";

    $repositories = array(
        //'repoCadIni' => "ESocialEventoCadIniRepository",
        'repoNaoPer' => "ESocialEventoNaoPerRepository",
        'repoPeriod' => "ESocialEventoPeriodRepository",
    );
    
    foreach ($repositories as $repositoryName) {
        $repository = __DIR__ . "/../../backend/src/HCM/Geral/Repository/" . $repositoryName . ".php";
        
        //Verifica se o arquivo de repositório existe
        if (file_exists($repository)) {
            echo " > Verificando $repositoryName...\n";
            $fileRepository = file($repository);
            
            //Pega os nomes dos métodos do repositório só para exibir qual ja teve a query verificada
            $repoMethods = get_class_methods('\\HCM\\Geral\\Repository\\'.$repositoryName);
            
            $countQueries = 0;  //Contador de queries verificadas
            $start = null;      //Linha inicial de uma query (<<<SQL)
            $end = null;        //Linha final de uma query (SQL;)
            $query = '';        //Query encontrada
            $params = array();  //Array de parâmetros passados para query encontrada
            
            //Loop nas linhas do arquivo de repositório para encontrar as queries e parâmetros
            foreach ($fileRepository as $line => $lineText) {
                //Pega a linha inicial da query a partir do texto '<<<SQL'
                if (strpos($lineText,"<<<SQL") !== false) {
                    $start = $line + 1;
                }
                
                //Pega a linha final da query a partir do texto 'SQL;'
                if (strpos($lineText,"SQL;") !== false) {
                    $end = $line - 1;
                }
                
                //Se encontrou o início e o fim do sql pega a query entre os pontos
                if (!is_null($start) && !is_null($end)) {
                    for ($i=$start; $i<=$end; $i++) {
                        $query .= $fileRepository[$i];
                    }
                    //Incrementa o contador de queries e limpa os pontos inicial e final para procurar a próxima query
                    $countQueries += 1;
                    $start = null;
                    $end = null;
                }
                
                //Pega os parâmetros passados logo após a query com a chamada 'params = array(...);' setando valor vazio para todos
                if (strpos($lineText,"params = array") !== false) {
                    $count = $line + 1;
                    while (strpos($fileRepository[$count],");") === false) {
                        $params[trim(current(explode('=>',$fileRepository[$count])),' "\'')] = '';
                        $count++;
                    };
                }
                
                //Se encontrou a query e os parâmetros valida a execução da query
                if (!empty($query) && !empty($params)) {
                    try {
                        //Valida a execução da query com os parâmetros
                        $result = QueryValidation::validateQuery($query,$params);
                        echo " > > $repoMethods[$countQueries] query validada com sucesso!\n";
                    } catch (\Exception $e) {
                        //Retorna a mensagem de erro da execução da query
                        echo " > > $repoMethods[$countQueries] query com erro: " . $e->getMessage() . "\n";
                    }
                    //Limpa a query e parâmetro encontrados para procurar os próximos
                    $query = '';
                    $params = array();
                }
            }
            echo " > $repositoryName com $countQueries validadas!\n";
        }
    }
    echo "Queries validadas com sucesso!\n";
}

class QueryValidation
{
    public static function validateQuery($query, $params=array())
    {
        return \Setforms2\Shared\Registry::getEntityManager()->getConnection()->fetchAll($query,$params);
    }
}

main();